scanFromImageRef method
Future<Result<CheckScanningResult> >
scanFromImageRef(
- ImageRef image,
- CheckScannerConfiguration configuration
Scans Check from a given image with the desired configuration.
image - The image to be used for scanning.
configuration - The Check scanner configuration to be used for scanning.
Returns a Future that completes with the result of the Check scanning operation.
Implementation
Future<Result<CheckScanningResult>> scanFromImageRef(
ImageRef image, CheckScannerConfiguration configuration) {
return ScanbotCheckImpl.scanFromImageRef(image, configuration);
}