ScanbotCreditCard class
Entry point for all Credit Card scanning features.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
scanFromImageFileUri(
String image, CreditCardScannerConfiguration configuration) → Future< Result< CreditCardScanningResult> > - Scans Credit Card from a given image with the desired configuration.
-
scanFromImageRef(
ImageRef image, CreditCardScannerConfiguration configuration) → Future< Result< CreditCardScanningResult> > - Scans Credit Card from a given image with the desired configuration.
-
startScanner(
CreditCardScannerScreenConfiguration configuration) → Future< Result< CreditCardScannerUiResult> > - Opens the Ready-To-Use UI Credit Card scanner with the desired configuration.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited