scanFromImageRef method

Scans Credit Card from a given image with the desired configuration.

image - The image to be used for scanning. configuration - The Credit Card scanner configuration to be used for scanning.

Returns a Future that completes with the result of the Credit Card scanning operation.

Implementation

Future<Result<CreditCardScanningResult>> scanFromImageRef(
    ImageRef image, CreditCardScannerConfiguration configuration) {
  return ScanbotCreditCardImpl.scanFromImageRef(image, configuration);
}