startScanner method

Opens the Ready-To-Use UI Credit Card scanner with the desired configuration.

configuration - The Credit Card scanner configuration to be used for scanning.

Returns a Future that completes with the result of the Credit Card scanning operation.

Implementation

Future<Result<CreditCardScannerUiResult>> startScanner(
    CreditCardScannerScreenConfiguration configuration) {
  return ScanbotCreditCardImpl.startScanner(configuration);
}