addPagesFromImageRefs method

Future<Result<DocumentData>> addPagesFromImageRefs(
  1. String documentUuid,
  2. List<ImageRef> images, {
  3. AddPageOptions? options,
})

Adds new pages from the provided images to the document with the specified Uuid.

documentUuid - The Uuid of the document to which pages will be added. images - The images to be added as new pages. options - The options to be used when adding pages.

Returns a Future that completes with updated document with added pages.

Implementation

Future<Result<DocumentData>> addPagesFromImageRefs(
    String documentUuid, List<ImageRef> images,
    {AddPageOptions? options}) {
  return ScanbotDocumentImpl.addPagesFromImageRefs(
      documentUuid, images, options);
}