createDocumentFromLegacyPages method
Creates a document from the provided legacy pages with the specified image size limit.
pages - The legacy pages to be used for document creation. Legacy filters that are set on the pages will be ignored. Please switch to ParametricFilters instead.
documentImageSizeLimit - The maximum size of the longest edge of the document image. If the image exceeds this limit, it will be downscaled proportionally. Default is 0
Returns a Future that completes with created document.
Implementation
@Deprecated('')
Future<Result<DocumentData>> createDocumentFromLegacyPages(List<Page> pages,
{int? documentImageSizeLimit}) {
return ScanbotDocumentImpl.createDocumentFromLegacyPages(
pages, documentImageSizeLimit);
}