documentExists method

Future<Result<bool>> documentExists(
  1. String documentUuid
)

Checks if a document with the specified Uuid exists.

documentUuid - The Uuid of the document.

Returns a Future that completes with true if the document exists, false otherwise.

Implementation

Future<Result<bool>> documentExists(String documentUuid) {
  return ScanbotDocumentImpl.documentExists(documentUuid);
}