movePage method

Future<Result<DocumentData>> movePage(
  1. String documentUuid,
  2. int fromIndex,
  3. int toIndex
)

Moves a page within the document to a new position.

documentUuid - The Uuid of the document containing the page to be moved. fromIndex - The index of the page to be moved. toIndex - The new index position for the page.

Returns a Future that completes with updated document with the page moved to the new position.

Implementation

Future<Result<DocumentData>> movePage(
    String documentUuid, int fromIndex, int toIndex) {
  return ScanbotDocumentImpl.movePage(documentUuid, fromIndex, toIndex);
}