removePages method

Future<Result<DocumentData>> removePages(
  1. String documentUuid,
  2. List<String> pageUuids
)

Removes pages with the specified Uuids from the document.

documentUuid - The Uuid of the document from which pages will be removed. pageUuids - The Uuids of the pages to be removed.

Returns a Future that completes with updated document with the specified pages removed.

Implementation

Future<Result<DocumentData>> removePages(
    String documentUuid, List<String> pageUuids) {
  return ScanbotDocumentImpl.removePages(documentUuid, pageUuids);
}