ScanbotDocumentDataExtractor class

Entry point for all Document Data Extractor features.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

extractFromImageFileUri(String image, DocumentDataExtractorConfiguration configuration) Future<Result<DocumentDataExtractionResult>>
Extracts data from a given image with the desired configuration.
extractFromImageRef(ImageRef image, DocumentDataExtractorConfiguration configuration) Future<Result<DocumentDataExtractionResult>>
Extracts data from a given image with the desired configuration.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startExtractorScreen(DocumentDataExtractorScreenConfiguration configuration) Future<Result<DocumentDataExtractorUiResult>>
Opens the Ready-To-Use UI Document Data Extractor screen with the desired configuration.
toString() String
A string representation of this object.
inherited
verifyDocument(List<GenericDocument> documentParts) Future<Result<DocumentVerificationReport>>
Verifies document parts.

Operators

operator ==(Object other) bool
The equality operator.
inherited