extractFromImageFileUri method

Future<Result<DocumentDataExtractionResult>> extractFromImageFileUri(
  1. String image,
  2. DocumentDataExtractorConfiguration configuration
)

Extracts data from a given image with the desired configuration.

image - The image to be used for extracting. configuration - The Document Data Extractor configuration to be used for extracting.

Returns a Future that completes with the result of the Document Data Extractor operation.

Implementation

Future<Result<DocumentDataExtractionResult>> extractFromImageFileUri(
    String image, DocumentDataExtractorConfiguration configuration) {
  return ScanbotDocumentDataExtractorImpl.extractFromImageFileUri(
      image, configuration);
}