startExtractorScreen method

Opens the Ready-To-Use UI Document Data Extractor screen with the desired configuration.

configuration - The Document Data Extractor configuration to be used for extracting.

Returns a Future that completes with the result of the Document Data Extractor operation.

Implementation

Future<Result<DocumentDataExtractorUiResult>> startExtractorScreen(
    DocumentDataExtractorScreenConfiguration configuration) {
  return ScanbotDocumentDataExtractorImpl.startExtractorScreen(configuration);
}