ScanbotDocumentEnhancer class

Entry point for all Document Enhancer features.

Constructors

ScanbotDocumentEnhancer()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

forceCloseDocumentCleanupScreen() → Future<Result<void>>
Forces the Ready-To-Use UI Document Cleanup screen to close if it is currently open.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startDocumentCleanupScreen(DocumentCleanupStandaloneConfiguration configuration) → Future<Result<DocumentData>>
Opens the Ready-To-Use UI screen to clean up the document using the provided configuration.
straightenImageFileUri(String image, DocumentStraighteningParameters straighteningParameters, {List<Point<double>>? priorCornersNormalized}) → Future<Result<DocumentStraighteningResult>>
Straightens the document effectively straightening its edges and text.
straightenImageRef(ImageRef image, DocumentStraighteningParameters straighteningParameters, {List<Point<double>>? priorCornersNormalized}) → Future<Result<DocumentStraighteningResult>>
Straightens the document effectively straightening its edges and text.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited