resizeImageFile method

Future<Result<String>> resizeImageFile(
  1. String imageFileUri,
  2. int maxSize, {
  3. bool? overwrite,
  4. SaveImageOptions? saveOptions,
})

Resizes the image to fit within the given maximum size for the longest edge.

imageFileUri - File uri of the image to be resized. maxSize - Maximum size for the longest edge of the image. overwrite - Whether to overwrite the original image file or create a new file. Default is false saveOptions - Options for saving the image.

Returns a Future that completes with file uri of the resized image.

Implementation

Future<Result<String>> resizeImageFile(String imageFileUri, int maxSize,
    {bool? overwrite, SaveImageOptions? saveOptions}) {
  return ScanbotImageProcessorImpl.resizeImageFile(
      imageFileUri, maxSize, overwrite, saveOptions);
}