rotate method

Future<Result<ImageRef>> rotate(
  1. ImageRef image,
  2. ImageRotation rotation
)

Rotates the image by the given rotation degree. This methods must be wrapped inside an autorelease pool.

image - Reference of the image to be rotated. rotation - Rotation degree.

Returns a Future that completes with reference of the rotated image.

Implementation

Future<Result<ImageRef>> rotate(ImageRef image, ImageRotation rotation) {
  return ScanbotImageProcessorImpl.rotate(image, rotation);
}