refreshImageUris method
Recreates the given pages to refresh the image uris.
pages - Pages to be recreated.
Returns a Future that completes with recreated pages with refreshed image uris.
Implementation
@Deprecated('')
Future<Result<List<Page>>> refreshImageUris(List<Page> pages) {
return ScanbotLegacyPageImpl.refreshImageUris(pages);
}