scanFromImageFileUri method

Future<Result<MrzScannerResult>> scanFromImageFileUri(
  1. String image,
  2. MrzScannerConfiguration configuration
)

Scans MRZ from a given image with the desired configuration.

image - The image to be used for scanning. configuration - The MRZ scanner configuration to be used for scanning.

Returns a Future that completes with the result of the MRZ scanning operation.

Implementation

Future<Result<MrzScannerResult>> scanFromImageFileUri(
    String image, MrzScannerConfiguration configuration) {
  return ScanbotMrzImpl.scanFromImageFileUri(image, configuration);
}