scanFromImageRef method
Future<Result<MrzScannerResult> >
scanFromImageRef(
- ImageRef image,
- MrzScannerConfiguration configuration
Scans MRZ from a given image with the desired configuration.
image - The image to be used for scanning.
configuration - The MRZ scanner configuration to be used for scanning.
Returns a Future that completes with the result of the MRZ scanning operation.
Implementation
Future<Result<MrzScannerResult>> scanFromImageRef(
ImageRef image, MrzScannerConfiguration configuration) {
return ScanbotMrzImpl.scanFromImageRef(image, configuration);
}