recognizeOnDocument method
Future<Result<PerformOcrResult> >
recognizeOnDocument(
- String documentUuid, {
- OcrConfiguration? configuration,
Performs OCR on the provided document with the specified configuration.
documentUuid - The Uuid of the document to be used for OCR processing.
configuration - The configuration for OCR processing.
Returns a Future that completes with the result of the OCR processing.
Implementation
Future<Result<PerformOcrResult>> recognizeOnDocument(String documentUuid,
{OcrConfiguration? configuration}) {
return ScanbotOcrEngineImpl.recognizeOnDocument(
documentUuid, configuration);
}