generateFromImageFileUris method

Future<Result<String>> generateFromImageFileUris(
  1. List<String> images,
  2. PdfConfiguration pdfConfiguration, {
  3. OcrConfiguration? ocrConfiguration,
})

Creates a PDF from the provided images with the specified configuration.

images - The list of images to be used for creating the PDF. pdfConfiguration - The configuration for the generated PDF. ocrConfiguration - The configuration for OCR processing.

Returns a Future that completes with the file uri pointing to the generated PDF file.

Implementation

Future<Result<String>> generateFromImageFileUris(
    List<String> images, PdfConfiguration pdfConfiguration,
    {OcrConfiguration? ocrConfiguration}) {
  return ScanbotPdfGeneratorImpl.generateFromImageFileUris(
      images, pdfConfiguration, ocrConfiguration);
}