ScanbotPdfImageExtractor class

Entry point for all PDF image extraction features.

Constructors

ScanbotPdfImageExtractor()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

extractImageFiles(String pdfFileUri, {PdfExtractorOptions? options}) → Future<Result<List<String>>>
Extract images from a PDF.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited