BarcodeScannerConfiguration class

Configuration of the barcode scanner screen.

Constructors

BarcodeScannerConfiguration({String version = "1.0", String screen = "BarcodeScanner", Palette? palette, BarcodeTextLocalization? localization, ScanbotColor? backgroundColor, TopBarConfiguration? topBar, ActionBarConfiguration? actionBar, ViewFinderConfiguration? viewFinder, UserGuidanceConfiguration? userGuidance, CameraPermissionScreen? cameraPermission, CameraConfiguration? cameraConfiguration, BarcodeRecognizerConfiguration? recognizerConfiguration, BarcodeUseCase? useCase, Sound? sound, Vibration? vibration, Timeouts? timeouts})
BarcodeScannerConfiguration.fromJson(Map<String, dynamic> json)
factory

Properties

actionBar ↔ ActionBarConfiguration
Configuration of the action bar.
getter/setter pair
backgroundColor ↔ ScanbotColor
Color of the screen's background. Default is "?sbColorSurfaceLow"
getter/setter pair
cameraConfiguration ↔ CameraConfiguration
Configuration of the camera behavior.
getter/setter pair
cameraPermission ↔ CameraPermissionScreen
Configuration of the dialog for requesting camera permissions.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
localization ↔ BarcodeTextLocalization
Configuration of the all strings for barcode scanner.
getter/setter pair
palette ↔ Palette
Define the screen's base color values from which other colors are derived.
getter/setter pair
recognizerConfiguration ↔ BarcodeRecognizerConfiguration
Configuration of the scanning behavior.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
screen → String
The configuration object should be applied for this screen. Default is "BarcodeScanner"
final
sound ↔ Sound
Configuration of the scan confirmation sound.
getter/setter pair
timeouts ↔ Timeouts
Configuration of timeouts.
getter/setter pair
topBar ↔ TopBarConfiguration
Configuration of the top bar.
getter/setter pair
useCase ↔ BarcodeUseCase
Configuration of the barcode scanner screen's behavior.
getter/setter pair
userGuidance ↔ UserGuidanceConfiguration
Configuration of the text hint guiding users to move the view finder over a barcode.
getter/setter pair
version → String
Version number of the configuration object. Default is "1.0"
final
vibration ↔ Vibration
Configuration of the scan scan confirmation vibration.
getter/setter pair
viewFinder ↔ ViewFinderConfiguration
Configuration of the view finder.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited