ButtonConfiguration class

Configuration of the button.

Constructors

ButtonConfiguration({bool visible = true, String text = "", String accessibilityDescription = "", BackgroundStyle? background, ForegroundStyle? foreground})
ButtonConfiguration.fromJson(Map<String, dynamic> json)
factory

Properties

accessibilityDescription ↔ String
The text to be read when the button is selected through accessibility mode. Default is ""
getter/setter pair
background ↔ BackgroundStyle
Configuration of the background appearance for the button.
getter/setter pair
foreground ↔ ForegroundStyle
Configuration of the appearance for foreground elements (e.g. text and/or icons, etc) of the button.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text ↔ String
The text to be displayed on the button. Default is ""
getter/setter pair
visible ↔ bool
Determines whether the button is visible or not. Default is true
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited