PolygonStyle class

Configuration of the polygon appearance.

Constructors

PolygonStyle({ScanbotColor? strokeColor, ScanbotColor? fillColor, double strokeWidth = 2.0, double cornerRadius = 0.0})
PolygonStyle.fromJson(Map<String, dynamic> json)
factory

Properties

cornerRadius ↔ double
The corner radius of the polygon in dp. Default is 0.0
getter/setter pair
fillColor ↔ ScanbotColor
The fill color of the polygon. Default is "#FFFFFF30"
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
strokeColor ↔ ScanbotColor
The color of the polygon outline. Default is "#FFFFFFFF"
getter/setter pair
strokeWidth ↔ double
The width of the polygon outline in dp. Default is 2.0
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited