RoundButton class

Configuration of the round button.

Constructors

RoundButton({bool visible = true, String accessibilityDescription = "", ScanbotColor? backgroundColor, ScanbotColor? foregroundColor, ScanbotColor? activeBackgroundColor, ScanbotColor? activeForegroundColor})
RoundButton.fromJson(Map<String, dynamic> json)
factory

Properties

accessibilityDescription ↔ String
The text to be read when the button is selected through accessibility mode. Default is ""
getter/setter pair
activeBackgroundColor ↔ ScanbotColor
The color of the button's background when the button is active (selected, toggled). Default is "#FFCE5C"
getter/setter pair
activeForegroundColor ↔ ScanbotColor
The color of the button's foreground (icon, text) when the button is active (selected, toggled). Default is "#1C1B1F"
getter/setter pair
backgroundColor ↔ ScanbotColor
The color of the button's background. Default is "#0000007A"
getter/setter pair
foregroundColor ↔ ScanbotColor
The color of the button's foreground (icon, text). Default is "#FFFFFF"
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
visible ↔ bool
Determines whether the button is visible or not. Default is true
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited