ScanbotAlertDialog class

Configuration of the the standard alert dialog.

Constructors

ScanbotAlertDialog({StyledText? title, StyledText? subtitle, ScanbotColor? sheetColor, ScanbotColor? modalOverlayColor, ScanbotColor? dividerColor, ButtonConfiguration? okButton, ButtonConfiguration? actionButton, ButtonConfiguration? cancelButton})
ScanbotAlertDialog.fromJson(Map<String, dynamic> json)
factory

Properties

actionButton ↔ ButtonConfiguration
Configuration of the middle button for dialogs with tree buttons.
getter/setter pair
cancelButton ↔ ButtonConfiguration
Configuration of the 'cancel' button.
getter/setter pair
dividerColor ↔ ScanbotColor
The color of the divider line. Default is "?sbColorOutline"
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
modalOverlayColor ↔ ScanbotColor
The dialog overlay color. Default is "?sbColorModalOverlay"
getter/setter pair
okButton ↔ ButtonConfiguration
Configuration of the 'OK' button.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sheetColor ↔ ScanbotColor
The background color of the alert dialog. Default is "?sbColorSurface"
getter/setter pair
subtitle ↔ StyledText
The explanation message.
getter/setter pair
title ↔ StyledText
The title displayed above the message.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited