Sound class

Configuration for the sound.

Constructors

Sound({bool successBeepEnabled = true, SoundType soundType = SoundType.MODERN_BEEP})
Sound.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
soundType ↔ SoundType
Determines the successful detection sound. Default is MODERN_BEEP
getter/setter pair
successBeepEnabled ↔ bool
Determine whether the beep sound should be enabled or not when a barcode is detected. Default is true
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited