AcknowledgementBottomBar class

Configuration of the bottom bar for the acknowledgement screen.

Constructors

AcknowledgementBottomBar({BarButtonConfiguration? retakeButton, BarButtonConfiguration? acceptWhenOkButton, BarButtonConfiguration? acceptWhenNotOkButton})
AcknowledgementBottomBar.fromJson(Map<String, dynamic> json)
factory

Properties

acceptWhenNotOkButton ↔ BarButtonConfiguration
Configuration of the 'accept' button, when the quality of the scanned page is unacceptable.
getter/setter pair
acceptWhenOkButton ↔ BarButtonConfiguration
Configuration of the 'accept' button, when the quality of the scanned page is acceptable.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
retakeButton ↔ BarButtonConfiguration
Configuration of the 'retake' button.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ToJsonConfiguration? config}) → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited