CameraBottomBar class

Configuration of the bottom bar for the camera screen.

Constructors

CameraBottomBar({BarButtonConfiguration? importButton, BarButtonConfiguration? autoSnappingModeButton, BarButtonConfiguration? manualSnappingModeButton, ShutterButton? shutterButton, BarButtonConfiguration? torchOnButton, BarButtonConfiguration? torchOffButton, PreviewButton? previewButton})
CameraBottomBar.fromJson(Map<String, dynamic> json)
factory

Properties

autoSnappingModeButton ↔ BarButtonConfiguration
Configuration of the 'auto snapping mode' button.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
importButton ↔ BarButtonConfiguration
Configuration of the 'import' button.
getter/setter pair
manualSnappingModeButton ↔ BarButtonConfiguration
Configuration of the 'manual snapping mode' button.
getter/setter pair
previewButton ↔ PreviewButton
Configuration of the 'preview' button.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shutterButton ↔ ShutterButton
Configuration of the 'shutter' button.
getter/setter pair
torchOffButton ↔ BarButtonConfiguration
Configuration of the 'flashlight' button when in the 'off' state.
getter/setter pair
torchOnButton ↔ BarButtonConfiguration
Configuration of the 'flashlight' button when in the 'on' state.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited