CameraScreenConfiguration class

Configuration of the screen for scanning the pages with the camera.

Constructors

CameraScreenConfiguration({AcknowledgementScreenConfiguration? acknowledgement, IntroductionScreenConfiguration? introduction, ScanAssistanceOverlay? scanAssistanceOverlay, CameraPermissionScreen? cameraPermission, StyledText? topBarTitle, IconButton? topBarIntroButton, ButtonConfiguration? topBarBackButton, UserGuidanceConfiguration? topUserGuidance, DocumentScannerUserGuidance? userGuidance, ScanbotColor? backgroundColor, DocumentScannerCameraConfiguration? cameraConfiguration, DocumentPolygonConfiguration? polygon, CameraBottomBar? bottomBar, ViewFinderConfiguration? viewFinder, CaptureFeedback? captureFeedback, Vibration? vibration, Timeouts? timeouts, ScanbotAlertDialog? limitReachedAlertDialog, ScanbotAlertDialog? cancelAlertDialog})
CameraScreenConfiguration.fromJson(Map<String, dynamic> json)
factory

Properties

acknowledgement ↔ AcknowledgementScreenConfiguration
Configuration of the acknowledgement screen.
getter/setter pair
backgroundColor ↔ ScanbotColor
The background color of the camera screen. Default is "#000000FF"
getter/setter pair
bottomBar ↔ CameraBottomBar
Configuration of the bottom bar for the camera screen.
getter/setter pair
cameraConfiguration ↔ DocumentScannerCameraConfiguration
Configuration of the camera behavior.
getter/setter pair
cameraPermission ↔ CameraPermissionScreen
Configuration of the camera permission screen.
getter/setter pair
cancelAlertDialog ↔ ScanbotAlertDialog
Configuration of the alert dialog displayed when the 'cancel' button is pressed.
getter/setter pair
captureFeedback ↔ CaptureFeedback
Configuration of the feedback shown after snapping a page.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
introduction ↔ IntroductionScreenConfiguration
Configuration of the introduction screen.
getter/setter pair
limitReachedAlertDialog ↔ ScanbotAlertDialog
Configuration of the alert dialog displayed when the scan limit is reached.
getter/setter pair
polygon ↔ DocumentPolygonConfiguration
Configuration of the document contour detection polygon.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scanAssistanceOverlay ↔ ScanAssistanceOverlay
Configuration of the scan assistance overlay.
getter/setter pair
timeouts ↔ Timeouts
Configuration of timeouts.
getter/setter pair
topBarBackButton ↔ ButtonConfiguration
Configuration of the 'cancel' button, located in the top bar.
getter/setter pair
topBarIntroButton ↔ IconButton
Configuration of the 'introduction' button, located in the top bar.
getter/setter pair
topBarTitle ↔ StyledText
Configuration of the title, located in the top bar.
getter/setter pair
topUserGuidance ↔ UserGuidanceConfiguration
Configuration of the static user guidance, located just below the top bar.
getter/setter pair
userGuidance ↔ DocumentScannerUserGuidance
Configuration of the hints guiding users through the scanning process.
getter/setter pair
vibration ↔ Vibration
Configuration of the scan confirmation vibration.
getter/setter pair
viewFinder ↔ ViewFinderConfiguration
Configuration of the viewfinder.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited