CroppingConfiguration class

Configuration of the standalone cropping screen.

Constructors

CroppingConfiguration({String version = "1.0", String screen = "CroppingConfiguration", Palette? palette, required String documentUuid, required String pageUuid, CroppingTextLocalization? localization, CroppingAppearanceConfiguration? appearance, CroppingScreenConfiguration? cropping, DocumentAnalysisMode documentAnalysisMode = DocumentAnalysisMode.UNFILTERED_DOCUMENT})
CroppingConfiguration.fromJson(Map<String, dynamic> json)
factory

Properties

appearance ↔ CroppingAppearanceConfiguration
Configuration of the general appearance for the cropping screen.
getter/setter pair
cropping ↔ CroppingScreenConfiguration
Configuration of the cropping screen.
getter/setter pair
documentAnalysisMode ↔ DocumentAnalysisMode
Determines if the quality analysis for the acknowledgement mode will run on the filtered or the unfiltered image. Default is UNFILTERED_DOCUMENT
getter/setter pair
documentUuid ↔ String
The UUID of the document to be cropped.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
localization ↔ CroppingTextLocalization
Configuration of all the strings for the standalone cropping screen.
getter/setter pair
pageUuid ↔ String
The UUID of the page of the document to be cropped.
getter/setter pair
palette ↔ Palette
Define the screen's base color values from which other colors are derived.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
screen ↔ String
The configuration object should be applied for this screen. Default is "CroppingConfiguration"
getter/setter pair
version ↔ String
Version number of the configuration object. Default is "1.0"
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited