CroppingResult class

Configuration of the cropping result.

Constructors

CroppingResult({required String documentUuid, required String pageUuid, String? errorMessage = null})
CroppingResult.fromJson(Map<String, dynamic> json)
factory

Properties

documentUuid → String
The UUID of the document that was cropped.
final
errorMessage → String?
The error message if a problem occurred.
final
hashCode → int
The hash code for this object.
no setterinherited
pageUuid → String
The UUID of the page of the document that was cropped.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ToJsonConfiguration? config}) → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited