CroppingScreenConfiguration class

Configuration of the screen for cropping the scanned pages.

Constructors

CroppingScreenConfiguration({ButtonConfiguration? topBarBackButton, StyledText? topBarTitle, ButtonConfiguration? topBarConfirmButton, ScanbotColor? backgroundColor, ScanbotColor? croppingHandlerColor, ScanbotColor? croppingPolygonColor, ScanbotColor? croppingPolygonMagneticLineColor, CroppingBottomBar? bottomBar})
CroppingScreenConfiguration.fromJson(Map<String, dynamic> json)
factory

Properties

backgroundColor ↔ ScanbotColor
The background color of the cropping screen.
getter/setter pair
bottomBar ↔ CroppingBottomBar
Configuration of the bottom bar for the cropping screen.
getter/setter pair
croppingHandlerColor ↔ ScanbotColor
The color of the cropping handles.
getter/setter pair
croppingPolygonColor ↔ ScanbotColor
The color of the cropping polygon.
getter/setter pair
croppingPolygonMagneticLineColor ↔ ScanbotColor
The color of the magnetic lines on the cropping polygon.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
topBarBackButton ↔ ButtonConfiguration
Configuration of the 'cancel' button, located in the top bar.
getter/setter pair
topBarConfirmButton ↔ ButtonConfiguration
Configuration of the 'confirm' button, located in the top bar.
getter/setter pair
topBarTitle ↔ StyledText
Configuration of the title, located in the top bar.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ToJsonConfiguration? config}) → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited