CroppingTextLocalization class

Configuration of all the strings for the standalone cropping screen.

Constructors

CroppingTextLocalization({String cameraProgressOverlayTitle = "Please wait...", String croppingTopBarCancelButtonTitle = "Cancel", String croppingTopBarConfirmButtonTitle = "Done", String croppingDetectButtonTitle = "Detect", String croppingRotateButtonTitle = "Rotate", String croppingResetButtonTitle = "Reset", String croppingScreenTitle = "Crop", String accessibilityDescriptionCroppingTopBarConfirmButton = "Tap to apply changes", String accessibilityDescriptionCroppingTopBarCancelButton = "Tap to close screen without applying changes", String accessibilityDescriptionCroppingDetectButton = "Tap to detect document on the image", String accessibilityDescriptionCroppingRotateButton = "Tap to rotate document", String accessibilityDescriptionCroppingResetButton = "Tap to reset document contour to whole image"})
CroppingTextLocalization.fromJson(Map<String, dynamic> json)
factory

Properties

accessibilityDescriptionCroppingDetectButton ↔ String
The accessibility hint for the 'detect document' button, located in the bottom bar of the cropping screen. Default is "Tap to detect document on the image"
getter/setter pair
accessibilityDescriptionCroppingResetButton ↔ String
The accessibility hint for the 'reset detection' button, located in the bottom bar of the cropping screen. Default is "Tap to reset document contour to whole image"
getter/setter pair
accessibilityDescriptionCroppingRotateButton ↔ String
The accessibility hint for the 'rotate page' button, located in the bottom bar of the cropping screen. Default is "Tap to rotate document"
getter/setter pair
accessibilityDescriptionCroppingTopBarCancelButton ↔ String
The accessibility hint for the 'cancel' button, located in the top bar of the cropping screen. Default is "Tap to close screen without applying changes"
getter/setter pair
accessibilityDescriptionCroppingTopBarConfirmButton ↔ String
The accessibility hint for the 'confirm' button, located in the top bar of the cropping screen. Default is "Tap to apply changes"
getter/setter pair
cameraProgressOverlayTitle ↔ String
The cropping progress overlay title. Default is "Please wait..."
getter/setter pair
croppingDetectButtonTitle ↔ String
The 'detect document' button title, located in the bottom bar of the cropping screen. Default is "Detect"
getter/setter pair
croppingResetButtonTitle ↔ String
The 'reset detection' button title, located in the bottom bar of the cropping screen. Default is "Reset"
getter/setter pair
croppingRotateButtonTitle ↔ String
The 'rotate page' button title, located in the bottom bar of the cropping screen. Default is "Rotate"
getter/setter pair
croppingScreenTitle ↔ String
The cropping screen title, located in the top bar. Default is "Crop"
getter/setter pair
croppingTopBarCancelButtonTitle ↔ String
The 'cancel' button title, located in the top bar of the cropping screen. Default is "Cancel"
getter/setter pair
croppingTopBarConfirmButtonTitle ↔ String
The 'confirm' button title, located in the top bar of the cropping screen. Default is "Done"
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited