DocumentScannerScreens class

Configuration of the document scanner sub-screens.

Properties

camera ↔ CameraScreenConfiguration
Configuration of the screen for scanning the pages with the camera.
getter/setter pair
cropping ↔ CroppingScreenConfiguration
Configuration of the screen for cropping the scanned pages.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
reorderPages ↔ ReorderPagesScreenConfiguration
Configuration of the screen for reordering the scanned pages.
getter/setter pair
review ↔ ReviewScreenConfiguration
Configuration of the screen for reviewing the scanned pages.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited