DocumentScannerUserGuidance class

Configuration of the hints guiding users through the scanning process.

Constructors

DocumentScannerUserGuidance({UserGuidanceVisibility visibility = UserGuidanceVisibility.ENABLED, StyledText? title, BackgroundStyle? background, UserGuidanceStates? statesTitles})
DocumentScannerUserGuidance.fromJson(Map<String, dynamic> json)
factory

Properties

background ↔ BackgroundStyle
Configure the background style for the user guidance hints.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statesTitles ↔ UserGuidanceStates
Configure the titles of the user guidance hints for different states.
getter/setter pair
title ↔ StyledText
Configure the text style for the user guidance hints.
getter/setter pair
visibility ↔ UserGuidanceVisibility
Determines when the user guidance hints should be visible. Default is ENABLED
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited