IntroListEntry class

An entry in the list of scanning steps of the introduction screen.

Constructors

IntroListEntry({IntroImage? image, StyledText? text})
IntroListEntry.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
image ↔ IntroImage
The image of the entry.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text ↔ StyledText
The text of the entry.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited