IntroductionScreenConfiguration class

Configuration of the introduction screen for the document scanner.

Constructors

IntroductionScreenConfiguration({ScanbotColor? backgroundColor, ScanbotColor? dividerColor, ScanbotColor? handlerColor, bool showAutomatically = false, ButtonConfiguration? topBarDoneButton, StyledText? title, StyledText? subtitle, List<IntroListEntry>? items})
IntroductionScreenConfiguration.fromJson(Map<String, dynamic> json)
factory

Properties

backgroundColor ↔ ScanbotColor
The background color of the introduction screen. Default is "?sbColorSurface"
getter/setter pair
dividerColor ↔ ScanbotColor
The divider color of the introduction screen. Default is "?sbColorOutline"
getter/setter pair
handlerColor ↔ ScanbotColor
The handle color of the introduction screen. Default is "?sbColorOutline"
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
items ↔ List<IntroListEntry>
Configure the scanning steps of the introduction screen.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showAutomatically ↔ bool
Determines whether the introduction screen should automatically be shown or not when the scanning session starts. Default is false
getter/setter pair
subtitle ↔ StyledText
The subtitle of the introduction screen.
getter/setter pair
title ↔ StyledText
The title of the introduction screen, located in the top bar.
getter/setter pair
topBarDoneButton ↔ ButtonConfiguration
Configuration of the 'done' button, located in the top bar.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited