ReorderPagesScreenConfiguration class

Configuration of the screen for reordering the scanned pages.

Constructors

ReorderPagesScreenConfiguration({ButtonConfiguration? topBarBackButton, StyledText? topBarTitle, ButtonConfiguration? topBarConfirmButton, ScanbotColor? backgroundColor, UserGuidanceConfiguration? guidance, StyledText? pageTextStyle})
ReorderPagesScreenConfiguration.fromJson(Map<String, dynamic> json)
factory

Properties

backgroundColor ↔ ScanbotColor
The background color of the reorder pages screen. Default is "?sbColorOutline"
getter/setter pair
guidance ↔ UserGuidanceConfiguration
Configuration of the static user guidance, located just below the top bar.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
pageTextStyle ↔ StyledText
Configuration of the title below each page object.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
topBarBackButton ↔ ButtonConfiguration
Configuration of the 'cancel' button, located in the top bar.
getter/setter pair
topBarConfirmButton ↔ ButtonConfiguration
Configuration of the 'confirm' button, located in the top bar.
getter/setter pair
topBarTitle ↔ StyledText
Configuration of the title, located in the top bar.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited