ReviewBottomBarConfiguration class

Configuration of the bottom bar for the review screen.

Properties

addButton ↔ BarButtonConfiguration
Configuration of the 'add' button, located in the bottom bar.
getter/setter pair
cropButton ↔ BarButtonConfiguration
Configuration of the 'crop' button, located in the bottom bar.
getter/setter pair
deleteButton ↔ BarButtonConfiguration
Configuration of the 'delete' button, located in the bottom bar.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
retakeButton ↔ BarButtonConfiguration
Configuration of the 'retake' button, located in the bottom bar.
getter/setter pair
rotateButton ↔ BarButtonConfiguration
Configuration of the 'rotate' button, located in the bottom bar.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
submitButton ↔ ButtonConfiguration
Configuration of the 'submit' button, located in the bottom bar.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited