ReviewScreenConfiguration class

Configuration of the screen for reviewing the scanned pages.

Constructors

ReviewScreenConfiguration({bool enabled = true, bool showLastPageWhenAdding = false, StyledText? topBarTitle, IconButton? topBarMoreButton, ButtonConfiguration? topBarBackButton, ReviewMorePopupMenu? morePopup, RoundButton? zoomButton, ZoomOverlay? zoomOverlay, ScanbotColor? backgroundColor, ReviewBottomBarConfiguration? bottomBar, IconButton? switchNextPageButton, IconButton? switchPreviousPageButton, UserGuidanceConfiguration? pageCounter, ScanbotAlertDialog? deleteAllPagesAlertDialog, ScanbotAlertDialog? deletePageAlertDialog})
ReviewScreenConfiguration.fromJson(Map<String, dynamic> json)
factory

Properties

backgroundColor ↔ ScanbotColor
The background color of the review screen.
getter/setter pair
bottomBar ↔ ReviewBottomBarConfiguration
Configuration of the bottom bar for the review screen.
getter/setter pair
deleteAllPagesAlertDialog ↔ ScanbotAlertDialog
Configuration of the alert dialog displayed when trying to delete all the pages.
getter/setter pair
deletePageAlertDialog ↔ ScanbotAlertDialog
Configuration of the alert dialog displayed when trying to delete a single page.
getter/setter pair
enabled ↔ bool
Determines whether the review screen should be shown or not. If 'false', the review screen will be skipped and the scanned document will be returned immediately.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
morePopup ↔ ReviewMorePopupMenu
Configuration of the 'more' popup menu for the review screen.
getter/setter pair
pageCounter ↔ UserGuidanceConfiguration
Configuration of the page count label.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showLastPageWhenAdding ↔ bool
If set to true, the review screen, after adding a page, will automatically scroll to the last page. Otherwise the review screen will scroll to the first page.
getter/setter pair
switchNextPageButton ↔ IconButton
Configuration of the 'next page' button.
getter/setter pair
switchPreviousPageButton ↔ IconButton
Configuration of the 'previous page' button.
getter/setter pair
topBarBackButton ↔ ButtonConfiguration
Configuration of the 'back' button, located in the top bar.
getter/setter pair
topBarMoreButton ↔ IconButton
Configuration of the 'more' button, located in the top bar.
getter/setter pair
topBarTitle ↔ StyledText
Configuration of the title, located in the top bar.
getter/setter pair
zoomButton ↔ RoundButton
Configuration of the 'zoom' button.
getter/setter pair
zoomOverlay ↔ ZoomOverlay
Configuration of the zoom overlay for the review screen.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ToJsonConfiguration? config}) → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited