ScanAssistanceOverlay class

Configuration of the scan assistance overlay.

Constructors

ScanAssistanceOverlay({bool visible = true, ScanbotColor? backgroundColor, ScanbotColor? foregroundColor})
ScanAssistanceOverlay.fromJson(Map<String, dynamic> json)
factory

Properties

backgroundColor ↔ ScanbotColor
The background color of the scan assistance overlay.
getter/setter pair
foregroundColor ↔ ScanbotColor
The foreground color of the scan assistance overlay image.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
visible ↔ bool
Determines whether the scan assistance overlay is visible or not. If the viewfinder is enabled, this flag is ignored and the scan assistance overlay is not displayed.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ToJsonConfiguration? config}) → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited