ZoomOverlay class

Configuration of the zoom overlay for the review screen.

Constructors

ZoomOverlay({ScanbotColor? overlayColor, ButtonConfiguration? closeButton})
ZoomOverlay.fromJson(Map<String, dynamic> json)
factory

Properties

closeButton ↔ ButtonConfiguration
Configuration of the 'close' button for the zoom overlay.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
overlayColor ↔ ScanbotColor
The background color of the zoom overlay.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ToJsonConfiguration? config}) → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited