BarcodeTextLocalization class

Configuration of the all strings for barcode scanner.

Constructors

BarcodeTextLocalization({String topBarCancelButton = "Cancel", String topBarTitle = "Scan Item", String userGuidance = "Move the finder over a barcode", String barcodeInfoMappingLoadingMessage = "Loading details...", String barcodeInfoMappingErrorStateTitle = "Connection Error!", String barcodeInfoMappingErrorStateSubtitle = "There was an issue and the data requested was not fetched. You could try again or discard this result to start a new scan.", String barcodeInfoMappingErrorStateRetryButton = "Retry", String barcodeInfoMappingErrorStateCancelButton = "Cancel", String manualCountEditDialogTitle = "Update count", String manualCountEditDialogInfo = "Adjust the number of items you scanned.", String manualCountEditDialogUpdateButton = "Update", String manualCountEditDialogCancelButton = "Cancel", String sheetResetButton = "Reset", String sheetClearAllButton = "Clear all", String sheetSubmitButton = "Submit", String sheetStartScanningButton = "Start scanning", String sheetPlaceholderTitle = "No barcodes here!", String sheetPlaceholderSubtitle = "The barcode list is currently empty. Close this sheet and scan your items to add them.", String singleModeConfirmationCancelButton = "Close", String multipleModeSheetTitle = "%d items", String findAndPickSheetTitle = "%d/%d scanned", String findAndPickSheetBarcodeItemSubtitle = "%d/%d added", String findAndPickPartialAlertTitle = "Incomplete scan!", String findAndPickPartialAlertSubtitle = "Some codes are yet to be scanned. Proceed with submission anyway?", String findAndPickPartialAlertCancelButton = "Cancel", String findAndPickPartialAlertSubmitButton = "Yes, Submit", String findAndPickCompleteAlertTitle = "All codes found!", String findAndPickCompleteAlertSubtitle = "You have successfully scanned all codes. Proceed with submission?", String findAndPickCompleteAlertCancelButton = "Dismiss", String findAndPickCompleteAlertSubmitButton = "Submit", String accessibilityDescriptionCancelButton = "Cancel", String accessibilityDescriptionFlashButton = "Toggle flash", String accessibilityStateFlashOnButton = "On", String accessibilityStateFlashOffButton = "Off", String accessibilityDescriptionZoomButton = "Toggle camera zoom", String accessibilityDescriptionFlipCameraButton = "Flip camera", String accessibilityStateFlipCameraBackButton = "Back", String accessibilityStateFlipCameraFrontButton = "Front", String cameraPermissionEnableCameraTitle = "Camera permission denied!", String cameraPermissionEnableCameraExplanation = "Please allow the usage of the camera to start the scanning process.", String cameraPermissionEnableCameraButton = "Grant permission", String cameraPermissionCloseButton = "Close", String accessibilityDescriptionCameraPermissionEnableCameraButton = "Tap to grant camera permission", String accessibilityDescriptionCameraPermissionCloseButton = "Close screen without granting permission"})
BarcodeTextLocalization.fromJson(Map<String, dynamic> json)
factory

Properties

accessibilityDescriptionCameraPermissionCloseButton ↔ String
The accessibility hint for the 'close' button of the camera permission dialog.
getter/setter pair
accessibilityDescriptionCameraPermissionEnableCameraButton ↔ String
The accessibility hint for the 'enable' button of the camera permission dialog.
getter/setter pair
accessibilityDescriptionCancelButton ↔ String
Accessibility description for the 'cancel' button in the top bar.
getter/setter pair
accessibilityDescriptionFlashButton ↔ String
Accessibility description for the flash button.
getter/setter pair
accessibilityDescriptionFlipCameraButton ↔ String
Accessibility description for the flip camera button.
getter/setter pair
accessibilityDescriptionZoomButton ↔ String
Accessibility description for the zoom button.
getter/setter pair
accessibilityStateFlashOffButton ↔ String
Accessibility value for the flash off button.
getter/setter pair
accessibilityStateFlashOnButton ↔ String
Accessibility value for the flash on button.
getter/setter pair
accessibilityStateFlipCameraBackButton ↔ String
Accessibility value for the flip camera back button.
getter/setter pair
accessibilityStateFlipCameraFrontButton ↔ String
Accessibility value for the flip camera front button.
getter/setter pair
barcodeInfoMappingErrorStateCancelButton ↔ String
Cancel button text for the barcode info mapping error state.
getter/setter pair
barcodeInfoMappingErrorStateRetryButton ↔ String
Retry button text for the barcode info mapping error state.
getter/setter pair
barcodeInfoMappingErrorStateSubtitle ↔ String
Subtitle for the barcode info mapping error state.
getter/setter pair
barcodeInfoMappingErrorStateTitle ↔ String
Title for the barcode info mapping error state.
getter/setter pair
barcodeInfoMappingLoadingMessage ↔ String
Loading message for barcode info mapping.
getter/setter pair
cameraPermissionCloseButton ↔ String
The 'close' button title of the camera permission dialog.
getter/setter pair
cameraPermissionEnableCameraButton ↔ String
The 'enable' button title of the camera permission dialog.
getter/setter pair
cameraPermissionEnableCameraExplanation ↔ String
The explanation text of the camera permission dialog.
getter/setter pair
cameraPermissionEnableCameraTitle ↔ String
The title of the camera permission dialog.
getter/setter pair
findAndPickCompleteAlertCancelButton ↔ String
Cancel button text for the find and pick complete alert.
getter/setter pair
findAndPickCompleteAlertSubmitButton ↔ String
Submit button text for the find and pick complete alert.
getter/setter pair
findAndPickCompleteAlertSubtitle ↔ String
Subtitle for the find and pick complete alert.
getter/setter pair
findAndPickCompleteAlertTitle ↔ String
Title for the find and pick complete alert.
getter/setter pair
findAndPickPartialAlertCancelButton ↔ String
Cancel button text for the find and pick partial alert.
getter/setter pair
findAndPickPartialAlertSubmitButton ↔ String
Submit button text for the find and pick partial alert.
getter/setter pair
findAndPickPartialAlertSubtitle ↔ String
Subtitle for the find and pick partial alert.
getter/setter pair
findAndPickPartialAlertTitle ↔ String
Title for the find and pick partial alert.
getter/setter pair
findAndPickSheetBarcodeItemSubtitle ↔ String
Subtitle for the find and pick barcode sheet.
getter/setter pair
findAndPickSheetTitle ↔ String
Title for the find and pick barcode sheet.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
manualCountEditDialogCancelButton ↔ String
Cancel button text for the manual count edit dialog.
getter/setter pair
manualCountEditDialogInfo ↔ String
Info for the manual count edit dialog.
getter/setter pair
manualCountEditDialogTitle ↔ String
Title for the manual count edit dialog.
getter/setter pair
manualCountEditDialogUpdateButton ↔ String
Update button text for the manual count edit dialog.
getter/setter pair
multipleModeSheetTitle ↔ String
Title for the multiple mode barcode sheet.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sheetClearAllButton ↔ String
Clear all button text for the barcode sheet.
getter/setter pair
sheetPlaceholderSubtitle ↔ String
Subtitle for the barcode sheet placeholder.
getter/setter pair
sheetPlaceholderTitle ↔ String
Title for the barcode sheet placeholder.
getter/setter pair
sheetResetButton ↔ String
Reset button text for the barcode sheet.
getter/setter pair
sheetStartScanningButton ↔ String
Start scanning button text for the barcode sheet.
getter/setter pair
sheetSubmitButton ↔ String
Submit button text for the barcode sheet.
getter/setter pair
singleModeConfirmationCancelButton ↔ String
Cancel button text for the single mode confirmation dialog.
getter/setter pair
topBarCancelButton ↔ String
Cancel button text for the top bar.
getter/setter pair
topBarTitle ↔ String
Title for the top bar.
getter/setter pair
userGuidance ↔ String
User guidance text.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ToJsonConfiguration? config}) → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited