CreditCardScannerScreenConfiguration class

Configuration of the screen for detecting credit card data.

Constructors

CreditCardScannerScreenConfiguration({String version = "1.0", String screen = "CreditCardScanner", CreditCardScannerScreenTextLocalization? localization, Palette? palette, ScanbotColor? backgroundColor, CameraConfiguration? cameraConfiguration, CameraPermissionScreen? cameraPermission, UserGuidanceConfiguration? topUserGuidance, CreditCardScanGuidanceConfiguration? scanStatusUserGuidance, TopBarConfiguration? topBar, ScanbotIconButton? topBarOpenIntroScreenButton, CreditCardScannerIntroScreenConfiguration? introScreen, ActionBarConfiguration? actionBar, PermanentViewFinderConfiguration? viewFinder, CreditCardScannerConfiguration? scannerConfiguration, bool exampleOverlayVisible = true, CreditCardScanningProgressConfiguration? scanningProgress, int scanIncompleteDataTimeout = 3000, ScanCompletionOverlay? successOverlay, ScanCompletionOverlay? incompleteDataOverlay, Sound? sound, Vibration? vibration, bool keepScreenOn = true})
CreditCardScannerScreenConfiguration.fromJson(Map<String, dynamic> json)
factory

Properties

actionBar ↔ ActionBarConfiguration
Configuration of the action bar.
getter/setter pair
backgroundColor ↔ ScanbotColor
The background color of the credit card scanner screen.
getter/setter pair
cameraConfiguration ↔ CameraConfiguration
Configuration of the camera behavior.
getter/setter pair
cameraPermission ↔ CameraPermissionScreen
Configuration of the dialog for requesting camera permissions.
getter/setter pair
exampleOverlayVisible ↔ bool
Flag to show or hide the preset button.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
incompleteDataOverlay ↔ ScanCompletionOverlay
Configuration of the success overlay.
getter/setter pair
introScreen ↔ CreditCardScannerIntroScreenConfiguration
Configuration of the introduction screen for the credit card scanner.
getter/setter pair
keepScreenOn ↔ bool
If enabled, the screen will not turn off while the credit card scanner is active.
getter/setter pair
localization ↔ CreditCardScannerScreenTextLocalization
Configuration of the all strings for credit card scanner screen.
getter/setter pair
palette ↔ Palette
Define the screen's base color values from which other colors are derived.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scanIncompleteDataTimeout ↔ int
Timeout for the scan process. If the scan process takes longer than this value, the incomplete result will be returned.
getter/setter pair
scannerConfiguration ↔ CreditCardScannerConfiguration
Configuration for the credit card recognizer.
getter/setter pair
scanningProgress ↔ CreditCardScanningProgressConfiguration
Configuration of visualization of the scanning progress.
getter/setter pair
scanStatusUserGuidance ↔ CreditCardScanGuidanceConfiguration
Configuration of the user guidance for the scanning status.
getter/setter pair
screen → String
The configuration object should be applied for this screen.
final
sound ↔ Sound
Configuration of the scan confirmation sound.
getter/setter pair
successOverlay ↔ ScanCompletionOverlay
Configuration of the success overlay.
getter/setter pair
topBar ↔ TopBarConfiguration
Configuration of the top bar on the credit card scanner screen.
getter/setter pair
topBarOpenIntroScreenButton ↔ ScanbotIconButton
Configuration of the button in the top bar that opens the introduction screen.
getter/setter pair
topUserGuidance ↔ UserGuidanceConfiguration
Configuration of the top user guidance.
getter/setter pair
version → String
Version number of the configuration object.
final
vibration ↔ Vibration
Configuration of the vibration feedback.
getter/setter pair
viewFinder ↔ PermanentViewFinderConfiguration
Configuration of the view finder.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ToJsonConfiguration? config}) → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited