DetectDocumentResult class

Annotations
  • @JsonSerializable.new(includeIfNull: true, explicitToJson: true, createFactory: true)

Constructors

DetectDocumentResult({required String documentImageFileUri, required List<PolygonPoint> polygon, required DocumentDetectionStatus detectionResult})
DetectDocumentResult.fromJson(Map<String, dynamic> json)
factory

Properties

detectionResult ↔ DocumentDetectionStatus
The result status of the document detection process.
getter/setter pair
documentImageFileUri ↔ String
The file URI of the detected document image.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
polygon ↔ List<PolygonPoint>
The polygon points representing the detected document boundary.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited