DocumentDataExtractionMode enum

The extraction mode.

Inheritance
Available extensions

Values

LIVE → const DocumentDataExtractionMode

The extractor will attempt to accumulate results over multiple frames.

SINGLE_SHOT → const DocumentDataExtractionMode

The extractor will only use the current frame and will spend additional time to ensure the best possible result.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<DocumentDataExtractionMode>
A constant List of the values in this enum, in order of their declaration.