minEstimatedNumberOfSymbolsForDocument property

int minEstimatedNumberOfSymbolsForDocument
getter/setter pair

If a document's estimated number of symbols is less than this value, document quality will be reported as UNCERTAIN. In that case, the deprecated result fields documentFound andqualityLevel will be set to false and empty, respectively.

Default is 20

Implementation

int minEstimatedNumberOfSymbolsForDocument;