DocumentScannerTextLocalization class

Configuration of all the strings for the standalone cropping screen.

Constructors

DocumentScannerTextLocalization({String cameraTopBarCancelButtonTitle = "Cancel", String cameraTopBarTitle = "Scan Document", String cameraTopGuidance = "Scan each page of your document.", String cameraUserGuidanceStart = "Please hold your device over a document.", String cameraUserGuidanceNoDocumentFound = "No document found", String cameraUserGuidanceAlreadyCropped = "Document already cropped. Move camera to fit document in the frame.", String cameraUserGuidanceBadAspectRatio = "Bad aspect ratio", String cameraUserGuidanceOrientationMismatch = "Orientation mismatch", String cameraUserGuidanceBadAngles = "Bad angles", String cameraUserGuidanceTooNoisy = "Its too noisy. Try another background for the document", String cameraUserGuidanceTextHintOffCenter = "Document is off center", String cameraUserGuidanceTooSmall = "Document is too small. Move camera closer.", String cameraUserGuidanceTooDark = "Its too dark. Add more light.", String cameraUserGuidanceEnergySaveMode = "Energy save mode is on", String cameraUserGuidanceReadyToCapture = "Hold still capturing...", String cameraUserGuidanceReadyToCaptureManual = "Ready to capture!", String cameraImportButtonTitle = "Import", String cameraTorchOnButtonTitle = "On", String cameraTorchOffButtonTitle = "Off", String cameraAutoSnapButtonTitle = "Auto", String cameraManualSnapButtonTitle = "Manual", String cameraPreviewButtonTitle = "%d Pages", String cameraBadgedPreviewButtonTitle = "Submit", String cameraIntroDoneButton = "Done", String cameraIntroTitle = "How to scan a document", String cameraIntroSubtitle = "Follow the steps below to create a high-quality document scan", String cameraIntroItem1 = "1. Place your document on a flat surface.", String cameraIntroItem2 = "2. Hold your phone above the document.", String cameraIntroItem3 = "3. Follow the on-screen guidance to find the optimal position.", String cameraIntroItem4 = "4. Once you reach the optimal position, you can manually scan the document or let the app scan it automatically.", String cameraProgressOverlayTitle = "Please wait...", String cameraCancelAlertTitle = "Cancel?", String cameraCancelAlertSubtitle = "Canceling will delete all the pages scanned so far. Are you sure you want to cancel?", String cameraCancelNoButtonTitle = "No", String cameraCancelYesButtonTitle = "Yes, Cancel", String cameraLimitReachedAlertTitle = "You reached the limit!", String cameraLimitReachedAlertSubtitle = "You have scanned the maximum number of pages and cannot add any more. Please delete at least one page to perform a new scan.", String cameraLimitReachedOkButtonTitle = "Ok", String acknowledgementRetakeButtonTitle = "Retake", String acknowledgementAcceptButtonTitle = "Use Scan", String proceedAnywayButtonDocumentNotFound = "Use Scan", String proceedAnywayButtonUnacceptableQuality = "Use Scan", String proceedAnywayButtonUncertainQuality = "Use Scan", String acknowledgementWarningDocumentNotFound = "No document detected. Continue or retake.", String acknowledgementWarningUnacceptableQuality = "Scan quality too low.", String acknowledgementWarningUncertainQuality = "Scan quality unclear. Continue or retake.", String reviewScreenTitle = "Review (%d)", String reviewTopBarBackButtonTitle = "Back", String reviewScreenPageCount = "Page %d/%d", String reviewScreenAddButtonTitle = "Add", String reviewScreenRetakeButtonTitle = "Retake", String reviewScreenCropButtonTitle = "Crop", String reviewScreenRotateButtonTitle = "Rotate", String reviewScreenDeleteButtonTitle = "Delete", String reviewScreenSubmitButtonTitle = "Submit", String reviewScreenDeleteAllButtonTitle = "Delete all", String reviewScreenReorderPagesButtonTitle = "Reorder pages", String zoomOverlayCancelButtonText = "Close", String reviewDeletePageAlertTitle = "Delete page?", String reviewDeleteAllPagesAlertTitle = "Delete all?", String reviewDeletePageAlertSubTitle = "Are you sure you want to delete the page?", String reviewDeleteAllPagesAlertSubtitle = "Are you sure you want to delete all pages?", String reviewDeletePageAlertConfirmButtonTitle = "Yes, Delete", String reviewDeleteAllPagesAlertDeleteButtonTitle = "Yes, Delete all", String reviewDeletePageAlertDeleteRetakeButtonTitle = "Delete and Retake", String reviewDeletePageAlertCancelButtonTitle = "Cancel", String reviewDeleteAllPagesAlertCancelButtonTitle = "Cancel", String reorderPageTitle = "Reorder Pages", String acknowledgementTitle = "Acknowledgement", String reorderPageGuidanceTitle = "Drag pages to reorder", String reorderPageText = "%d", String reorderTopBarConfirmButtonTitle = "Done", String reorderTopBarCancelButtonTitle = "Cancel", String croppingTopBarConfirmButtonTitle = "Done", String croppingTopBarCancelButtonTitle = "Cancel", String croppingDetectButtonTitle = "Detect", String croppingRotateButtonTitle = "Rotate", String croppingResetButtonTitle = "Reset", String croppingScreenTitle = "Crop", String accessibilityDescriptionCameraTopBarIntroButton = "Tap to open introduction screen", String accessibilityDescriptionCameraTopBarCancelButton = "Tap to close scanner screen", String accessibilityDescriptionCameraImportButton = "Tap to import image", String accessibilityDescriptionCameraTorchOnButton = "Tap to disable torch", String accessibilityDescriptionCameraTorchOffButton = "Tap to enable torch", String accessibilityDescriptionCameraShutterButton = "Tap to take image", String accessibilityDescriptionCameraAutoSnapButton = "Tap to enable manual snapping mode", String accessibilityDescriptionCameraManualSnapButton = "Tap to enable auto snapping mode", String accessibilityDescriptionCameraPreviewButton = "Tap to preview scanned pages", String accessibilityDescriptionCameraIntroDoneButton = "Tap to close introduction screen", String accessibilityDescriptionAcknowledgementRetakeButton = "Tap to retake the image", String accessibilityDescriptionAcknowledgementAcceptButton = "Tap to accept the image regardless of its quality", String accessibilityDescriptionProceedAnywayButtonDocumentNotFound = "Tap to proceed with scan despite no document being found", String accessibilityDescriptionProceedAnywayButtonUnacceptableQuality = "Tap to proceed with scan despite unacceptable quality", String accessibilityDescriptionProceedAnywayButtonUncertainQuality = "Tap to proceed with scan despite uncertain quality", String accessibilityDescriptionAcknowledgementWarning = "Quality warning message", String accessibilityDescriptionAcknowledgementWarningDocumentNotFound = "Warning No document found in the image", String accessibilityDescriptionAcknowledgementWarningUnacceptableQuality = "Warning Document quality is unacceptable", String accessibilityDescriptionAcknowledgementWarningUncertainQuality = "Warning Document quality is uncertain", String accessibilityDescriptionCroppingTopBarConfirmButton = "Tap to apply changes", String accessibilityDescriptionCroppingTopBarCancelButton = "Tap to close screen without applying changes", String accessibilityDescriptionCroppingDetectButton = "Tap to detect document on the image", String accessibilityDescriptionCroppingRotateButton = "Tap to rotate document", String accessibilityDescriptionCroppingResetButton = "Tap to reset document contour to whole image", String accessibilityDescriptionReorderTopBarConfirmButton = "Tap to apply changes", String accessibilityDescriptionReorderTopBarCancelButton = "Tap to close screen without applying changes", String accessibilityDescriptionReviewNextPageButton = "Tap to switch to the new page", String accessibilityDescriptionReviewPreviousPageButton = "Tap to switch to the previous page", String accessibilityDescriptionReviewAddButton = "Tap to Add new page", String accessibilityDescriptionReviewRetakeButton = "Tap to Retake current selected page", String accessibilityDescriptionReviewCropButton = "Tap to Crop selected page", String accessibilityDescriptionReviewRotateButton = "Tap to Rotate selected page clockwise", String accessibilityDescriptionReviewDeleteButton = "Tap to Delete selected page", String accessibilityDescriptionReviewSubmitButton = "Tap to Submit document", String accessibilityDescriptionReviewMoreButton = "Tap to show additional options", String accessibilityDescriptionReviewDeleteAllButton = "Tap to Delete all pages", String accessibilityDescriptionReviewReorderPagesButton = "Tap to Reorder pages", String accessibilityDescriptionZoomOverlayCancelButton = "Tap to Close zoom overlay", String accessibilityDescriptionReviewZoomButton = "Tap to open zoom overlay for selected page", String accessibilityDescriptionReviewTopBarBackButton = "Tap to Close review screen", String accessibilityDescriptionReviewDeletePageAlertConfirmButton = "Tap to Delete page", String accessibilityDescriptionReviewDeleteAllPagesAlertDeleteButton = "Tap to Delete all pages", String accessibilityDescriptionReviewDeletePageAlertDeleteRetakeButton = "Tap to Delete page and Retake it", String accessibilityDescriptionReviewDeletePageAlertCancelButton = "Tap to Cancel operation", String accessibilityDescriptionReviewDeleteAllPagesAlertCancelButton = "Tap to Cancel operation", String accessibilityDescriptionCameraLimitReachedOkButton = "Tap to close alert dialog", String accessibilityDescriptionCameraCancelYesButton = "Tap to cancel document", String accessibilityDescriptionCameraCancelNoButton = "Tap to close alert dialog", String accessibilityDescriptionDocumentImagePreview = "Document image preview", String cameraPermissionEnableCameraTitle = "Camera permission denied!", String cameraPermissionEnableCameraExplanation = "Please allow the usage of the camera to start the scanning process.", String cameraPermissionEnableCameraButton = "Grant permission", String cameraPermissionCloseButton = "Close", String accessibilityDescriptionCameraPermissionEnableCameraButton = "Tap to grant camera permission", String accessibilityDescriptionCameraPermissionCloseButton = "Close screen without granting permission"})
DocumentScannerTextLocalization.fromJson(Map<String, dynamic> json)
factory

Properties

accessibilityDescriptionAcknowledgementAcceptButton String
The accessibility hint for the 'accept' button of the acknowledgement screen.
getter/setter pair
accessibilityDescriptionAcknowledgementRetakeButton String
The accessibility hint for the 'retake' button of the acknowledgement screen.
getter/setter pair
accessibilityDescriptionAcknowledgementWarning String
The accessibility hint for the acknowledgement warning display.
getter/setter pair
accessibilityDescriptionAcknowledgementWarningDocumentNotFound String
The accessibility hint for the acknowledgement warning when document is not found.
getter/setter pair
accessibilityDescriptionAcknowledgementWarningUnacceptableQuality String
The accessibility hint for the acknowledgement warning when document quality is unacceptable.
getter/setter pair
accessibilityDescriptionAcknowledgementWarningUncertainQuality String
The accessibility hint for the acknowledgement warning when document quality is uncertain.
getter/setter pair
accessibilityDescriptionCameraAutoSnapButton String
The accessibility hint for the 'auto snapping' mode button, located in the bottom bar of the camera screen.
getter/setter pair
accessibilityDescriptionCameraCancelNoButton String
The accessibility hint for the 'no' button of the cancel camera screen alert dialog.
getter/setter pair
accessibilityDescriptionCameraCancelYesButton String
The accessibility hint for the 'yes' button of the cancel camera screen alert dialog.
getter/setter pair
accessibilityDescriptionCameraImportButton String
The accessibility hint for the 'import image' button, located in the bottom bar of the camera screen.
getter/setter pair
accessibilityDescriptionCameraIntroDoneButton String
The accessibility hint for the 'done' button of the introduction screen.
getter/setter pair
accessibilityDescriptionCameraLimitReachedOkButton String
The accessibility hint for the 'OK' button of the page limit reached alert dialog.
getter/setter pair
accessibilityDescriptionCameraManualSnapButton String
The accessibility hint for the 'manual snapping' mode button, located in the bottom bar of the camera screen.
getter/setter pair
accessibilityDescriptionCameraPermissionCloseButton String
The accessibility hint for the 'close' button of the camera permission dialog.
getter/setter pair
accessibilityDescriptionCameraPermissionEnableCameraButton String
The accessibility hint for the 'enable' button of the camera permission dialog.
getter/setter pair
accessibilityDescriptionCameraPreviewButton String
The accessibility hint for the 'preview' button, located in the bottom bar of the camera screen.
getter/setter pair
accessibilityDescriptionCameraShutterButton String
The accessibility hint for the 'shutter' button, located in the bottom bar of the camera screen.
getter/setter pair
accessibilityDescriptionCameraTopBarCancelButton String
The accessibility hint for the 'cancel' button, located in the top bar of the camera screen.
getter/setter pair
accessibilityDescriptionCameraTopBarIntroButton String
The accessibility hint for the 'introduction' button, located in the top bar of the camera screen.
getter/setter pair
accessibilityDescriptionCameraTorchOffButton String
The accessibility hint for the 'flashlight off' button, located in the bottom bar of the camera screen.
getter/setter pair
accessibilityDescriptionCameraTorchOnButton String
The accessibility hint for the 'flashlight on' button, located in the bottom bar of the camera screen.
getter/setter pair
accessibilityDescriptionCroppingDetectButton String
The accessibility hint for the 'detect document' button, located in the bottom bar of the cropping screen.
getter/setter pair
accessibilityDescriptionCroppingResetButton String
The accessibility hint for the 'reset detection' button, located in the bottom bar of the cropping screen.
getter/setter pair
accessibilityDescriptionCroppingRotateButton String
The accessibility hint for the 'rotate page' button, located in the bottom bar of the cropping screen.
getter/setter pair
accessibilityDescriptionCroppingTopBarCancelButton String
The accessibility hint for the 'cancel' button, located in the top bar of the cropping screen.
getter/setter pair
accessibilityDescriptionCroppingTopBarConfirmButton String
The accessibility hint for the 'confirm' button, located in the top bar of the cropping screen.
getter/setter pair
accessibilityDescriptionDocumentImagePreview String
The accessibility description for the preview document image on the review screen.
getter/setter pair
accessibilityDescriptionProceedAnywayButtonDocumentNotFound String
The accessibility hint for the 'proceed anyway' button when document is not found.
getter/setter pair
accessibilityDescriptionProceedAnywayButtonUnacceptableQuality String
The accessibility hint for the 'proceed anyway' button when document quality is unacceptable.
getter/setter pair
accessibilityDescriptionProceedAnywayButtonUncertainQuality String
The accessibility hint for the 'proceed anyway' button when document quality is uncertain.
getter/setter pair
accessibilityDescriptionReorderTopBarCancelButton String
The accessibility hint for the 'cancel' button, located in the top bar of the reorder pages screen.
getter/setter pair
accessibilityDescriptionReorderTopBarConfirmButton String
The accessibility hint for the 'confirm' button, located in the top bar of the reorder pages screen.
getter/setter pair
accessibilityDescriptionReviewAddButton String
The accessibility hint for the 'add' button, located in the bottom bar of the review screen.
getter/setter pair
accessibilityDescriptionReviewCropButton String
The accessibility hint for the 'crop' button, located in the bottom bar of the review screen.
getter/setter pair
accessibilityDescriptionReviewDeleteAllButton String
The accessibility hint for the 'delete all' menu button, accessed via the 'more' button of the review screen.
getter/setter pair
accessibilityDescriptionReviewDeleteAllPagesAlertCancelButton String
The accessibility hint for the 'cancel' button of the delete all pages alert dialog for the review screen.
getter/setter pair
accessibilityDescriptionReviewDeleteAllPagesAlertDeleteButton String
The accessibility hint for the 'confirm' button of the delete all pages alert dialog for the review screen.
getter/setter pair
accessibilityDescriptionReviewDeleteButton String
The accessibility hint for the 'delete' button, located in the bottom bar of the review screen.
getter/setter pair
accessibilityDescriptionReviewDeletePageAlertCancelButton String
The accessibility hint for the 'cancel' button of the delete page alert dialog for the review screen.
getter/setter pair
accessibilityDescriptionReviewDeletePageAlertConfirmButton String
The accessibility hint for the 'confirm' button of the delete page alert dialog for the review screen.
getter/setter pair
accessibilityDescriptionReviewDeletePageAlertDeleteRetakeButton String
The accessibility hint for the 'delete and retake' button of the delete page alert dialog for the review screen.
getter/setter pair
accessibilityDescriptionReviewMoreButton String
The accessibility hint for the 'more' button, located in the top bar of the review screen.
getter/setter pair
accessibilityDescriptionReviewNextPageButton String
The accessibility hint for the 'next page' button of the review screen.
getter/setter pair
accessibilityDescriptionReviewPreviousPageButton String
The accessibility hint for the 'previous page' button of the review screen.
getter/setter pair
accessibilityDescriptionReviewReorderPagesButton String
The accessibility hint for the 'reorder pages' menu button, accessed via the 'more' button of the review screen.
getter/setter pair
accessibilityDescriptionReviewRetakeButton String
The accessibility hint for the 'retake' button, located in the bottom bar of the review screen.
getter/setter pair
accessibilityDescriptionReviewRotateButton String
The accessibility hint for the 'rotate' button, located in the bottom bar of the review screen.
getter/setter pair
accessibilityDescriptionReviewSubmitButton String
The accessibility hint for the 'submit' button, located in the bottom bar of the review screen.
getter/setter pair
accessibilityDescriptionReviewTopBarBackButton String
The accessibility hint for the 'back' button, located in the top bar of the review screen.
getter/setter pair
accessibilityDescriptionReviewZoomButton String
The accessibility hint for the 'zoom' button of the review screen.
getter/setter pair
accessibilityDescriptionZoomOverlayCancelButton String
The accessibility hint for the 'close' button of the zoom overlay for the review screen.
getter/setter pair
acknowledgementAcceptButtonTitle String
The 'accept' button title of the acknowledgement screen.
getter/setter pair
acknowledgementRetakeButtonTitle String
The 'retake' button title of the acknowledgement screen.
getter/setter pair
acknowledgementTitle String
The title of the acknowledgement screen, located in the top bar.
getter/setter pair
acknowledgementWarningDocumentNotFound String
The warning text when document is not found.
getter/setter pair
acknowledgementWarningUnacceptableQuality String
The warning text when document quality is unacceptable.
getter/setter pair
acknowledgementWarningUncertainQuality String
The warning text when document quality is uncertain.
getter/setter pair
cameraAutoSnapButtonTitle String
The 'auto snapping' mode button title, located in the bottom bar of the camera screen.
getter/setter pair
cameraBadgedPreviewButtonTitle String
The 'preview' button title, located in the bottom bar of the camera screen. With the badge showing the number of captured pages.
getter/setter pair
cameraCancelAlertSubtitle String
The subtitle of the cancel camera screen alert dialog.
getter/setter pair
cameraCancelAlertTitle String
The title of the cancel camera screen alert dialog.
getter/setter pair
cameraCancelNoButtonTitle String
The 'no' button title of the cancel camera screen alert dialog.
getter/setter pair
cameraCancelYesButtonTitle String
The 'yes' button title of the cancel camera screen alert dialog.
getter/setter pair
cameraImportButtonTitle String
The 'import image' button title, located in the bottom bar of the camera screen.
getter/setter pair
cameraIntroDoneButton String
The 'done' button title of the introduction screen, located in the top bar.
getter/setter pair
cameraIntroItem1 String
The first scanning step text of the introduction screen.
getter/setter pair
cameraIntroItem2 String
The second scanning step text of the introduction screen.
getter/setter pair
cameraIntroItem3 String
The third scanning step text of the introduction screen.
getter/setter pair
cameraIntroItem4 String
The fourth scanning step text of the introduction screen.
getter/setter pair
cameraIntroSubtitle String
The subtitle of the introduction screen.
getter/setter pair
cameraIntroTitle String
The title of the introduction screen, located in the top bar.
getter/setter pair
cameraLimitReachedAlertSubtitle String
The subtitle of the page limit reached alert dialog.
getter/setter pair
cameraLimitReachedAlertTitle String
The title of the page limit reached alert dialog.
getter/setter pair
cameraLimitReachedOkButtonTitle String
The 'OK' button title of the page limit reached alert dialog.
getter/setter pair
cameraManualSnapButtonTitle String
The 'manual snapping' mode button title, located in the bottom bar of the camera screen.
getter/setter pair
cameraPermissionCloseButton String
The 'close' button title of the camera permission dialog.
getter/setter pair
cameraPermissionEnableCameraButton String
The 'enable' button title of the camera permission dialog.
getter/setter pair
cameraPermissionEnableCameraExplanation String
The explanation text of the camera permission dialog.
getter/setter pair
cameraPermissionEnableCameraTitle String
The title of the camera permission dialog.
getter/setter pair
cameraPreviewButtonTitle String
The 'preview' button title, located in the bottom bar of the camera screen. '%d' denotes the total number of captured pages.
getter/setter pair
cameraProgressOverlayTitle String
The progress overlay title that is displayed on the camera screen during processing.
getter/setter pair
cameraTopBarCancelButtonTitle String
The 'cancel' button title, located in the top bar of the camera screen and the reorder pages screen.
getter/setter pair
cameraTopBarTitle String
The title of the camera screen, located in the top bar.
getter/setter pair
cameraTopGuidance String
The text for the static user guidance, located just below the top bar of the camera screen.
getter/setter pair
cameraTorchOffButtonTitle String
The 'flashlight off' button title, located in the bottom bar of the camera screen.
getter/setter pair
cameraTorchOnButtonTitle String
The 'flashlight on' button title, located in the bottom bar of the camera screen.
getter/setter pair
cameraUserGuidanceAlreadyCropped String
The user guidance text displayed when a document is found but borders are outside the image.
getter/setter pair
cameraUserGuidanceBadAngles String
The user guidance text displayed when the document pitch/skew angle is unacceptable.
getter/setter pair
cameraUserGuidanceBadAspectRatio String
The user guidance text displayed a detected documents aspect ratio is not within the acceptable range.
getter/setter pair
cameraUserGuidanceEnergySaveMode String
The user guidance text displayed when the device is in energy saving mode. iOS only.
getter/setter pair
cameraUserGuidanceNoDocumentFound String
The user guidance text displayed when no document is found.
getter/setter pair
cameraUserGuidanceOrientationMismatch String
The user guidance text displayed when a landscape document is detected when the camera is in portrait mode (and vice versa).
getter/setter pair
cameraUserGuidanceReadyToCapture String
The user guidance text displayed when the document is ready to be captured in 'auto snapping' mode.
getter/setter pair
cameraUserGuidanceReadyToCaptureManual String
The user guidance text displayed when the document is ready to be captured in 'manual snapping' mode.
getter/setter pair
cameraUserGuidanceStart String
The user guidance text that is initially displayed, before a document is detected.
getter/setter pair
cameraUserGuidanceTextHintOffCenter String
The user guidance text displayed when the document is not centered in the finder view.
getter/setter pair
cameraUserGuidanceTooDark String
The user guidance text displayed when it is too dark to capture an adequate image.
getter/setter pair
cameraUserGuidanceTooNoisy String
The user guidance text displayed when the background is too noisy.
getter/setter pair
cameraUserGuidanceTooSmall String
The user guidance text displayed when the document is too far from camera.
getter/setter pair
croppingDetectButtonTitle String
The 'detect document' button title, located in the bottom bar of the cropping screen.
getter/setter pair
croppingResetButtonTitle String
The 'reset detection' button title, located in the bottom bar of the cropping screen.
getter/setter pair
croppingRotateButtonTitle String
The 'rotate page' button title, located in the bottom bar of the cropping screen.
getter/setter pair
croppingScreenTitle String
The title of the cropping screen, located in the top bar.
getter/setter pair
croppingTopBarCancelButtonTitle String
The 'cancel' button title, located in the top bar of the cropping screen.
getter/setter pair
croppingTopBarConfirmButtonTitle String
The 'confirm' button title, located in the top bar of the cropping screen.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
proceedAnywayButtonDocumentNotFound String
The proceed anyway button title when document is not found.
getter/setter pair
proceedAnywayButtonUnacceptableQuality String
The proceed anyway button title when document quality is unacceptable.
getter/setter pair
proceedAnywayButtonUncertainQuality String
The proceed anyway button title when document quality is uncertain.
getter/setter pair
reorderPageGuidanceTitle String
The text for the static user guidance, located just below the top bar of the reorder pages screen.
getter/setter pair
reorderPageText String
The title below each page object of the reorder pages screen. '%d' denotes the current page number.
getter/setter pair
reorderPageTitle String
The title of the reorder pages screen, located in the top bar.
getter/setter pair
reorderTopBarCancelButtonTitle String
The 'cancel' button title, located in the top bar of the reorder pages screen.
getter/setter pair
reorderTopBarConfirmButtonTitle String
The 'confirm' button title, located in the top bar of the reorder pages screen.
getter/setter pair
reviewDeleteAllPagesAlertCancelButtonTitle String
The 'cancel' button title of the delete all pages alert dialog for the review screen.
getter/setter pair
reviewDeleteAllPagesAlertDeleteButtonTitle String
The 'confirm' button title of the delete all pages alert dialog for the review screen.
getter/setter pair
reviewDeleteAllPagesAlertSubtitle String
The subtitle of the delete all pages alert dialog for the review screen.
getter/setter pair
reviewDeleteAllPagesAlertTitle String
The title of the delete all pages alert dialog for the review screen.
getter/setter pair
reviewDeletePageAlertCancelButtonTitle String
The 'cancel' button title of the delete page alert dialog for the review screen.
getter/setter pair
reviewDeletePageAlertConfirmButtonTitle String
The 'confirm' button title of the delete page alert dialog for the review screen.
getter/setter pair
reviewDeletePageAlertDeleteRetakeButtonTitle String
The 'delete and retake' button title of the delete page alert dialog for the review screen.
getter/setter pair
reviewDeletePageAlertSubTitle String
The subtitle of the delete page alert dialog for the review screen.
getter/setter pair
reviewDeletePageAlertTitle String
The title of the delete page alert dialog for the review screen.
getter/setter pair
reviewScreenAddButtonTitle String
The 'add' button title, located in the bottom bar of the review screen.
getter/setter pair
reviewScreenCropButtonTitle String
The 'crop' button title, located in the bottom bar of the review screen.
getter/setter pair
reviewScreenDeleteAllButtonTitle String
The 'delete all' menu button title, accessed via the 'more' button of the review screen.
getter/setter pair
reviewScreenDeleteButtonTitle String
The 'delete' button title, located in the bottom bar of the review screen.
getter/setter pair
reviewScreenPageCount String
The page count label text. The first occurrence of '%d' denotes the current page number, while the second occurrence of '%d' denotes the total number of captured pages.
getter/setter pair
reviewScreenReorderPagesButtonTitle String
The 'reorder pages' menu button title, accessed via the 'more' button of the review screen.
getter/setter pair
reviewScreenRetakeButtonTitle String
The 'retake' button title, located in the bottom bar of the review screen.
getter/setter pair
reviewScreenRotateButtonTitle String
The 'rotate' button title, located in the bottom bar of the review screen.
getter/setter pair
reviewScreenSubmitButtonTitle String
The 'submit' button title, located in the bottom bar of the review screen.
getter/setter pair
reviewScreenTitle String
The title of the review screen, located in the top bar. '%d' denotes the total number of captured pages.
getter/setter pair
reviewTopBarBackButtonTitle String
The 'back' button title, located in the top bar of the review screen.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
zoomOverlayCancelButtonText String
The 'close' button title of the zoom overlay for the review screen.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ToJsonConfiguration? config}) Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited