FieldValueSemantics class

Report of the field value semantics verification.

Constructors

FieldValueSemantics({required String fieldFullName, required bool invalidSemantics})
FieldValueSemantics.fromJson(Map<String, dynamic> json)
factory

Properties

fieldFullName → String
Full name of the field that was considered during the verification.
final
hashCode → int
The hash code for this object.
no setterinherited
invalidSemantics → bool
Shows whether the data in the field is semantically invalid, e.g. the date of birth is in the future.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ToJsonConfiguration? config}) → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited