ModifyPageOptions class

Options for modifying a page within a document.

Constructors

ModifyPageOptions({ImageRotation rotation = ImageRotation.NONE, List<Point<double>>? polygon, List<ParametricFilter>? filters})
ModifyPageOptions.fromJson(Map<String, dynamic> json)
factory

Properties

filters List<ParametricFilter>?
The list of filters applied to the page. If not specified, no filters are applied.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
polygon List<Point<double>>?
The polygon to which the page will be cropped. If not specified, no cropping is applied.
getter/setter pair
rotation ImageRotation
The type of rotation to apply.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ToJsonConfiguration? config}) Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited