PartiallyVisibleDocumentConfiguration class

Configuration for handling partially visible documents.

Constructors

PartiallyVisibleDocumentConfiguration({bool allowPartiallyVisibleDocuments = false, int accumulationDuration = 700, int retentionTime = 1500, int minimumBrightness = 0})
PartiallyVisibleDocumentConfiguration.fromJson(Map<String, dynamic> json)
factory

Properties

accumulationDuration int
Live mode only: Duration in milliseconds over which the document has to be detected as partially visible. If on any frame the document is not detected as partially visible, or detected as having a completely different Displacement, the accumulation will be reset. During the accumulation, the document scanner will return a status of ERROR_NOTHING_DETECTED instead of one of the partially visible statuses. Set to 0 to disable this behavior.
getter/setter pair
allowPartiallyVisibleDocuments bool
If true, the document scanner will return a status of ERROR_PARTIALLY_VISIBLE or ERROR_PARTIALLY_VISIBLE_TOO_CLOSE if a document-like shape is detected, but not all four corners of the document are visible. If false, a status of ERROR_NOTHING_DETECTED will be returned instead.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
minimumBrightness int
Minimum brightness of a partially visible potential document. Increasing this value can reduce the number of spurious detections.
getter/setter pair
retentionTime int
Live mode only: Time in milliseconds during which the detection status ERROR_NOTHING_DETECTED is changed to ERROR_PARTIALLY_VISIBLE_TOO_CLOSE if no document was detected following the detection of a partially visible document. Set to 0 to disable this behavior.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ToJsonConfiguration? config}) Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited