RoIdCardTD3 class

RoIdCardTD3

Inheritance

Constructors

RoIdCardTD3(GenericDocument document)

Properties

address TextFieldWrapper
Address
no setter
birthplace TextFieldWrapper
Birthplace
no setter
document GenericDocument
finalinherited
expiryDate TextFieldWrapper
Expiry date
no setter
gender TextFieldWrapper
Gender
no setter
givenNames TextFieldWrapper
Given Names
no setter
hashCode int
The hash code for this object.
no setterinherited
id TextFieldWrapper
Series and number of the ID card
no setter
issuingAuthority TextFieldWrapper
Issuing authority
no setter
metadata Metadata
The child document of type "Metadata".
no setter
mrz MRZ
The child document of type "MRZ".
no setter
nationality TextFieldWrapper
Nationality
no setter
personalNumber TextFieldWrapper
Personal Number (CNP)
no setter
photo TextFieldWrapper
Photo image
no setter
rawMRZ TextFieldWrapper
Raw MRZ text value
no setter
requiredDocumentType String
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
surname TextFieldWrapper
Surname
no setter
validFromDate TextFieldWrapper
Valid from date
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

DOCUMENT_NORMALIZED_TYPE → const String
Normalized document type name of this document wrapper.
DOCUMENT_TYPE → const String
Generic document type name of this document wrapper.