TiffGeneratorParameters class

TIFF generator parameters.

Constructors

TiffGeneratorParameters({CompressionMode compression = CompressionMode.LZW, int jpegQuality = 80, int zipCompressionLevel = 6, int dpi = 72, List<UserField>? userFields, ParametricFilter? binarizationFilter})
TiffGeneratorParameters.fromJson(Map<String, dynamic> json)
factory

Properties

binarizationFilter ↔ ParametricFilter?
Filter to apply to the input image when adding pages with binarization. If set, the filter is applied to the input image and the resulting image is stored as a 1-bit TIFF. When storing documents it's typically best to use the BINARY_DOCUMENT_OPTIMIZED_COMPRESSION compression mode (CCITT_T6) instead of the default, as it tends to produce the smallest file sizes. If not set, simple thresholding is applied to the image, instead.
getter/setter pair
compression ↔ CompressionMode
Compression.
getter/setter pair
dpi ↔ int
DPI value.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
jpegQuality ↔ int
JPEG quality (TIFFTAG_JPEGQUALITY). Values range from 0 to 100.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userFields ↔ List<UserField>
User-defined fields.
getter/setter pair
zipCompressionLevel ↔ int
ZIP/Deflate compression level (TIFFTAG_ZIPQUALITY). Values range from 1 to 9.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ToJsonConfiguration? config}) → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

binaryDocumentOptimizedCompression → CompressionMode
Compression mode typically producing the smallest file sizes for binary (1-bit) document images.
final
defaultCompression → CompressionMode
Default compression.
final