CheckUserGuidanceStrings class

Configuration that helps to override default hint values.

Annotations
  • @JsonSerializable.new(includeIfNull: false, createFactory: false, explicitToJson: true)

Constructors

CheckUserGuidanceStrings(String? startScanning, String? scanning, String? energySaving, String? capturing, String? processing)

Properties

capturing ↔ String?
Text that is shown when the camera snaps the image.
getter/setter pair
energySaving ↔ String?
Text text that is shown when energy saving is active.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
processing ↔ String?
Text that is shown when the detector tries to detect the document from the snapped image.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scanning ↔ String?
Text text that is shown when the camera is seeking for the document on the visible area, shown after the first result from the detector.
getter/setter pair
startScanning ↔ String?
Text that is shown on camera open.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited