CroppingScreenConfiguration class

Cropping rtu-ui component configuration class

Annotations
  • @JsonSerializable.new(createFactory: false, includeIfNull: false, explicitToJson: true)

Constructors

CroppingScreenConfiguration({Color? backgroundColor, Color? bottomBarBackgroundColor, Color? bottomBarButtonsColor, String? cancelButtonTitle, String? doneButtonTitle, Color? polygonColor, Color? polygonColorMagnetic, int? polygonLineWidth, String? rotateButtonTitle, Color? topBarBackgroundColor, Color? topBarButtonsColor, String? topBarTitle, Color? titleColor, String? detectButtonTitle, String? resetButtonTitle, bool? rotateButtonHidden, bool? detectResetButtonHidden, OrientationLockMode? orientationLockMode})

Properties

backgroundColor ↔ Color?
Background color of the main screen.
getter/setter pair
bottomBarBackgroundColor ↔ Color?
Background color of the bottom toolbar.
getter/setter pair
bottomBarButtonsColor ↔ Color?
The color of the titles of all buttons in the bottom toolbar (Rotate button).
getter/setter pair
cancelButtonTitle ↔ String?
Title of the cancel button.
getter/setter pair
detectButtonTitle ↔ String?
Title of the Detect button.
getter/setter pair
detectResetButtonHidden ↔ bool?
Controls whether the Detect/Reset button is hidden or not.
getter/setter pair
doneButtonTitle ↔ String?
Title of the Done button.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
orientationLockMode ↔ OrientationLockMode?
UI orientation lock mode: PORTRAIT, LANDSCAPE, etc. By default the UI is not locked.
getter/setter pair
polygonColor ↔ Color?
Default color of the cropping outline.
getter/setter pair
polygonColorMagnetic ↔ Color?
Outline color of magnetically snapped edges.
getter/setter pair
polygonLineWidth ↔ int?
Width of the cropping outline.
getter/setter pair
resetButtonTitle ↔ String?
Title of the Reset button.
getter/setter pair
rotateButtonHidden ↔ bool?
Controls whether the Rotate button is hidden or not.
getter/setter pair
rotateButtonTitle ↔ String?
Title of the Rotate button.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
titleColor ↔ Color?
The color of the title in the top bar (iOS only).
getter/setter pair
topBarBackgroundColor ↔ Color?
Background color of the top toolbar.
getter/setter pair
topBarButtonsColor ↔ Color?
The color of the titles of all buttons in the top toolbar (Cancel and Done buttons).
getter/setter pair
topBarTitle ↔ String?
Title in the top bar (iOS only).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited