FinderDocumentScannerConfiguration class

Annotations
  • @JsonSerializable.new(includeIfNull: false, createFactory: false, explicitToJson: true)

Constructors

FinderDocumentScannerConfiguration({String? version, String? screen, double? acceptedAngleScore, double? acceptedSizeScore, double? acceptedBrightnessThreshold, bool? autoSnappingEnabled, double? autoSnappingSensitivity, double? autoSnappingDelay, CameraModule? cameraModule, Color? cameraBackgroundColor, CameraPreviewMode? cameraPreviewMode, bool? touchToFocusEnabled, String? cameraUnavailableExplanationText, String? cancelButtonTitle, ImageFilterType? defaultPageFilter, DocumentScannerEngineMode? engineMode, String? enableCameraButtonTitle, String? enableCameraExplanationText, bool? flashButtonHidden, bool? flashEnabled, bool? forceUserGuidance, bool? finderEnabled, Color? finderLineColor, double? finderLineWidth, Color? cameraOverlayColor, AspectRatio? finderAspectRatio, bool? ignoreOrientationMismatch, double? imageScale, OrientationLockMode? orientationLockMode, CapturePhotoQualityPrioritization? photoQualityPrioritization, bool? polygonEnabled, Color? polygonBackgroundColor, Color? polygonBackgroundColorOK, Color? polygonColor, Color? polygonColorOK, double? polygonLineWidth, double? polygonCornerRadius, Color? autoSnapProgressColor, double? autoSnapProgressLineWidth, bool? autoSnapProgressEnabled, bool? lockDocumentAspectRatioToFinder, Color? shutterButtonAutoInnerColor, Color? shutterButtonAutoOuterColor, Color? shutterButtonIndicatorColor, Color? shutterButtonManualInnerColor, Color? shutterButtonManualOuterColor, bool? stopsCameraSessionWhenDisappeared, String? textHintBadAngles, String? textHintBadAspectRatio, String? textHintNothingDetected, String? textHintOffCenter, String? textHintOK, String? textHintTooDark, String? textHintTooNoisy, String? textHintTooSmall, Color? topBarBackgroundColor, Color? topBarButtonsActiveColor, Color? topBarButtonsInactiveColor, Color? userGuidanceBackgroundColor, Color? userGuidanceTextColor, double? userGuidanceFontSize, Size? documentImageSizeLimit, bool? shutterButtonHidden, String? textHintEnergySavingActive, bool? useButtonsAllCaps, FinderDocumentScannerAccessibilityConfiguration? accessibilityConfiguration})

Properties

acceptedAngleScore ↔ double?
Minimum score in percent (0 - 100) of the accepted perspective distortion of the detected document. Default is 75.0.
getter/setter pair
acceptedBrightnessThreshold ↔ double?
The brightness threshold to accept a detected document in the range of 0 (very dark) to 255 (very bright). If the average brightness value of the detectors input image is below this value, the status of the detection will be set to ERROR_TOO_DARK.
getter/setter pair
acceptedSizeScore ↔ double?
Minimum score in percent (0 - 100) of accepted document width or height to screen size ratio of the detected document. Default is 80.0.
getter/setter pair
accessibilityConfiguration ↔ FinderDocumentScannerAccessibilityConfiguration?
Allows you to customize the accessibility configuration for the Document Scanner UI.
getter/setter pair
autoSnappingDelay ↔ double?
Minimum delay in seconds between two consecutive automatic image captures. iOS only.
getter/setter pair
autoSnappingEnabled ↔ bool?
Whether to enable auto-snapping. If enabled, the document scanner will take a photo automatically when a document is detected, conditions are good and the auto-snapping time-out elapses. In this mode, the user can still tap the shutter button to snap a document.
getter/setter pair
autoSnappingSensitivity ↔ double?
Controls the auto-snapping speed. Sensitivity must be within the 0..1 range. A value of 1.0 triggers automatic capturing immediately, a value of 0.0 delays the automatic capturing by 3 seconds. Default value is 0.66 (2 seconds).
getter/setter pair
autoSnapProgressColor ↔ Color?
Stroke color of the polygon or the finder's auto-snap progress animation. Default is green. Can't be nil.
getter/setter pair
autoSnapProgressEnabled ↔ bool?
Whether to enable the polygon or finder's auto-snap progress animation. Default is true.
getter/setter pair
autoSnapProgressLineWidth ↔ double?
Line width of the polygon or the finder's auto-snap progress animation. Default is 5.0.
getter/setter pair
cameraBackgroundColor ↔ Color?
Color of the camera background (relevant only when the camera preview mode is CameraPreviewMode.FIT_IN).
getter/setter pair
cameraModule ↔ CameraModule?
Preferred camera module (Default: BACK).
getter/setter pair
cameraOverlayColor ↔ Color?
Background color outside of the finder window.
getter/setter pair
cameraPreviewMode ↔ CameraPreviewMode?
Preview mode of the camera. Fit-In or Fill-In.
getter/setter pair
cameraUnavailableExplanationText ↔ String?
String being displayed on the label describing that the app is in split mode and needs to go fullscreen to work with the camera. iOS only.
getter/setter pair
cancelButtonTitle ↔ String?
Title of the cancel button.
getter/setter pair
defaultPageFilter ↔ ImageFilterType?
Default image filter type for new document pages. Defaults to ImageFilterTypeNone.
getter/setter pair
documentImageSizeLimit ↔ Size?
Limits the maximum size of the document image. If the width or height are zero, this property is effectively ignored.
getter/setter pair
enableCameraButtonTitle ↔ String?
Title of the button that opens the screen where the user can allow the usage of the camera by the app.
getter/setter pair
enableCameraExplanationText ↔ String?
Text that will be displayed when the app is not allowed to use the camera, prompting the user to enable the usage of the camera.
getter/setter pair
engineMode ↔ DocumentScannerEngineMode?
Document scanner mode to be used for detecting the document outline. Defaults to ML. iOS only. For Android, use the Scanbot SDK initializer.
getter/setter pair
finderAspectRatio ↔ AspectRatio?
Aspect ratio of the finder frame (width to height), which is used to build the actual finder frame. Default is the DIN A4 aspect ratio.
getter/setter pair
finderEnabled ↔ bool?
Whether to enable the view finder.
getter/setter pair
finderLineColor ↔ Color?
Foreground color of the detection overlay.
getter/setter pair
finderLineWidth ↔ double?
Width of finder frame border. Default is 2.
getter/setter pair
flashButtonHidden ↔ bool?
Whether the flash toggle button is hidden.
getter/setter pair
flashEnabled ↔ bool?
Whether the flash should be initially enabled. The default value is FALSE.
getter/setter pair
forceUserGuidance ↔ bool?
Whether to show the user guidance elements if auto-snapping is disabled.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
ignoreOrientationMismatch ↔ bool?
Sets whether to ignore the OK_BUT_ORIENTATION_MISMATCH detection status. By default OrientationMismatch is not ignored.
getter/setter pair
imageScale ↔ double?
Image scaling factor. The factor must be within the 0..1 range. A factor of 1 means that the resulting images retain their original size. When the factor is less than 1, resulting images will be made smaller by that factor. By default the scale is 1.
getter/setter pair
lockDocumentAspectRatioToFinder ↔ bool?
Whether to allow scanning only for documents with the same aspect ratio as the finder.
getter/setter pair
orientationLockMode ↔ OrientationLockMode?
Mode for locking the UI's orientation.
getter/setter pair
photoQualityPrioritization ↔ CapturePhotoQualityPrioritization?
Prioritization of still image quality and capturing speed. Defaults to CapturePhotoQualityPrioritization.BALANCED. If you experience lots of blurry still images, try to set this property to CapturePhotoQualityPrioritization.QUALITY. iOS only.
getter/setter pair
polygonBackgroundColor ↔ Color?
Background color of the detected document's outline when the document's angle, size or aspect ratio is not yet sufficiently good. (All net.doo.snap.lib.detector.DetectionResult with OK_BUT_XXX.)
getter/setter pair
polygonBackgroundColorOK ↔ Color?
Background color of the detected document's outline when ready to snap.
getter/setter pair
polygonColor ↔ Color?
Color of the detected document's outline when the document's angle, size or aspect ratio is not yet sufficiently good. (All detection statuses in net.doo.snap.lib.detector.DetectionResult that have the OK_BUT_XXX prefix.)
getter/setter pair
polygonColorOK ↔ Color?
Color of the detected document's outline when ready to snap.
getter/setter pair
polygonCornerRadius ↔ double?
Radius to use when drawing rounded corners of the polygon. Default is 8.0.
getter/setter pair
polygonEnabled ↔ bool?
Whether to display the document's polygon.
getter/setter pair
polygonLineWidth ↔ double?
Width of the detected document's outline.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
screen ↔ String?
Screen for which the configuration object should be applied.
getter/setter pair
shutterButtonAutoInnerColor ↔ Color?
Foreground color of the shutter button in auto-snapping mode.
getter/setter pair
shutterButtonAutoOuterColor ↔ Color?
Background color of the shutter button in auto-snapping mode.
getter/setter pair
shutterButtonHidden ↔ bool?
Whether to hide the shutter button. Defaults to TRUE. If set to TRUE, auto-snapping is enabled and the property autoSnappingEnabled of the behavior configuration will have no effect. Also the auto-snapping button will be hidden.
getter/setter pair
shutterButtonIndicatorColor ↔ Color?
Indicator color of the shutter button in auto-snapping mode. iOS only.
getter/setter pair
shutterButtonManualInnerColor ↔ Color?
Foreground color of the shutter button in manual mode.
getter/setter pair
shutterButtonManualOuterColor ↔ Color?
Background color of the shutter button in manual mode.
getter/setter pair
stopsCameraSessionWhenDisappeared ↔ bool?
If true, the camera session is stopped entirely when the receiver disappears and restarted when the receiver reappears. Else, will pause the delivery of video frames. Defaults to True. iOS only.
getter/setter pair
textHintBadAngles ↔ String?
Text hint that will be shown when the current detection status is OK_BUT_BAD_ANGLES.
getter/setter pair
textHintBadAspectRatio ↔ String?
Text hint that will be shown when the current detection status is OK_BUT_BAD_ASPECT_RATIO.
getter/setter pair
textHintEnergySavingActive ↔ String?
Text hint that will be shown when the scanner's energy saver is activated. iOS only.
getter/setter pair
textHintNothingDetected ↔ String?
Text hint that will be shown when the current detection status is ERROR_NOTHING_DETECTED.
getter/setter pair
textHintOffCenter ↔ String?
Text hint that will be show when a document was detected, but its center is too far away from the image center.
getter/setter pair
textHintOK ↔ String?
Text hint that will be shown when the current detection status is OK.
getter/setter pair
textHintTooDark ↔ String?
Text hint that will be shown when the current detection status is ERROR_TOO_DARK.
getter/setter pair
textHintTooNoisy ↔ String?
Text hint that will be shown when the current detection status is ERROR_TOO_NOISY.
getter/setter pair
textHintTooSmall ↔ String?
Text hint that will be shown when the current detection status is OK_BUT_TOO_SMALL.
getter/setter pair
topBarBackgroundColor ↔ Color?
Background color of the top toolbar.
getter/setter pair
topBarButtonsActiveColor ↔ Color?
Color of all active toggle buttons in the toolbar.
getter/setter pair
topBarButtonsInactiveColor ↔ Color?
Color of all inactive toggle buttons in the toolbar.
getter/setter pair
touchToFocusEnabled ↔ bool?
Whether touch-to-focus is enabled on camera preview. Enabled by default. Android only.
getter/setter pair
useButtonsAllCaps ↔ bool?
Whether buttons should use all-capitals style, as defined by the Android Material Design. Defaults to TRUE. Android only.
getter/setter pair
userGuidanceBackgroundColor ↔ Color?
Background color of the user guidance hints.
getter/setter pair
userGuidanceFontSize ↔ double?
Font size of the user guidance. Default is 17.0.
getter/setter pair
userGuidanceTextColor ↔ Color?
Text color of the user guidance hints.
getter/setter pair
version ↔ String?
Version number of the configuration object.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited