HealthInsuranceCardRecognizerParameters class

The live detection configuration parameters.

Annotations
  • @JsonSerializable.new(includeIfNull: false, createFactory: false, explicitToJson: true)

Constructors

HealthInsuranceCardRecognizerParameters(List<HealthInsuranceCardCountryType>? acceptedCountries, int? minBirthYear, int? maxBirthYear, int? minExpirationYear, int? maxExpirationYear, int? maxCountryDetectionAttempts, int? maxAccumulatedFrameCount, int? minEqualFrameCount)

Properties

acceptedCountries ↔ List<HealthInsuranceCardCountryType>?
List of allowed countries for the health insurance card recognizer.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
maxAccumulatedFrameCount ↔ int?
Maximum number of partial frame results to keep in cache while waiting to gather minEqualFrameCount equal results.
getter/setter pair
maxBirthYear ↔ int?
Maximum of birth-year.
getter/setter pair
maxCountryDetectionAttempts ↔ int?
Maximum number of attempts before giving up on country detection.
getter/setter pair
maxExpirationYear ↔ int?
Maximum ranges of card-expiration-year.
getter/setter pair
minBirthYear ↔ int?
Minimum of birth-year.
getter/setter pair
minEqualFrameCount ↔ int?
Minimum number of accumulated frames that should have equal result for a field.
getter/setter pair
minExpirationYear ↔ int?
Minimum of card-expiration-year.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited