HealthInsuranceCardScannerConfiguration class

Annotations
  • @JsonSerializable.new(includeIfNull: false, createFactory: false, explicitToJson: true)

Constructors

HealthInsuranceCardScannerConfiguration({String? version, String? screen, CameraModule? cameraModule, Color? cameraOverlayColor, String? cancelButtonTitle, bool? cancelButtonHidden, String? detectionStatusFailedDetectionText, String? detectionStatusFailedValidationText, String? detectionStatusSuccessText, String? enableCameraButtonTitle, String? enableCameraExplanationText, Color? finderLineColor, double? finderLineWidth, String? finderTextHint, Color? finderTextHintColor, bool? flashButtonHidden, String? flashButtonTitle, bool? flashEnabled, OrientationLockMode? orientationLockMode, Color? topBarBackgroundColor, Color? topBarButtonsActiveColor, Color? topBarButtonsInactiveColor, bool? useButtonsAllCaps, bool? replaceCancelButtonWithIcon, CameraPreviewMode? cameraPreviewMode, bool? touchToFocusEnabled, HealthInsuranceCardRecognizerParameters? recognizerParameters})

Properties

cameraModule ↔ CameraModule?
The preferred camera module (default - BACK)
getter/setter pair
cameraOverlayColor ↔ Color?
Background color outside of the finder window.
getter/setter pair
cameraPreviewMode ↔ CameraPreviewMode?
Preview mode of the camera. FILL_IN or FIT_IN. Default is FILL_IN. Android only
getter/setter pair
cancelButtonHidden ↔ bool?
Whether the cancel button is hidden or not. iOS only.
getter/setter pair
cancelButtonTitle ↔ String?
Title of the cancel button.
getter/setter pair
detectionStatusFailedDetectionText ↔ String?
String being displayed when health insurance card was not found.
getter/setter pair
detectionStatusFailedValidationText ↔ String?
String being displayed when health insurance card was found but not recognized.
getter/setter pair
detectionStatusSuccessText ↔ String?
String being displayed when health insurance card was found and recognized.
getter/setter pair
enableCameraButtonTitle ↔ String?
Title of the button that opens the screen where the user can allow the usage of the camera by the app.
getter/setter pair
enableCameraExplanationText ↔ String?
Text that will be displayed when the app is not allowed to use the camera, prompting the user to enable the usage of the camera.
getter/setter pair
finderLineColor ↔ Color?
Foreground color of the detection overlay.
getter/setter pair
finderLineWidth ↔ double?
Width of finder frame border. Default is 2.
getter/setter pair
finderTextHint ↔ String?
String being displayed as description.
getter/setter pair
finderTextHintColor ↔ Color?
Foreground color of the description label.
getter/setter pair
flashButtonHidden ↔ bool?
Controls whether the flash toggle button is hidden or not. iOS only.
getter/setter pair
flashButtonTitle ↔ String?
Title of the flash toggle button. iOS only.
getter/setter pair
flashEnabled ↔ bool?
Controls whether the flash should be initially enabled. The default value is FALSE.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
orientationLockMode ↔ OrientationLockMode?
UI Interface orientation lock mode
getter/setter pair
recognizerParameters ↔ HealthInsuranceCardRecognizerParameters?
The live detection configuration parameters.
getter/setter pair
replaceCancelButtonWithIcon ↔ bool?
If true, replaces the cancel button in the top bar with a back arrow icon. The default value is FALSE. Android only.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
screen ↔ String?
The configuration object should be applied for this screen
getter/setter pair
topBarBackgroundColor ↔ Color?
The background color of the top toolbar.
getter/setter pair
topBarButtonsActiveColor ↔ Color?
The color of all active toggle buttons in the toolbar.
getter/setter pair
topBarButtonsInactiveColor ↔ Color?
The color of all inactive toggle buttons in the toolbar.
getter/setter pair
touchToFocusEnabled ↔ bool?
Whether touch-to-focus is enabled on camera preview. Enabled by default. Android only.
getter/setter pair
useButtonsAllCaps ↔ bool?
Controls whether buttons should use all capitals style, as defined by the Android Material Design. Defaults to TRUE. Android only.
getter/setter pair
version ↔ String?
A version of the configuration object
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited