VinScannerScreenConfiguration class

Annotations
  • @JsonSerializable.new(includeIfNull: false, createFactory: false, explicitToJson: true)

Constructors

VinScannerScreenConfiguration({String? version, String? screen, CameraModule? cameraModule, Color? cameraOverlayColor, String? cancelButtonTitle, bool? cancelButtonHidden, String? enableCameraButtonTitle, String? enableCameraExplanationText, Color? finderLineColor, double? finderLineWidth, Color? finderTextHintColor, bool? flashButtonHidden, String? flashButtonTitle, bool? flashEnabled, OrientationLockMode? orientationLockMode, Color? topBarBackgroundColor, Color? topBarButtonsActiveColor, Color? topBarButtonsInactiveColor, bool? extractVINFromBarcode, int? minimumNumberOfRequiredFramesWithEqualScanningResult, int? maximumNumberOfAccumulatedFrames, int? ocrResolutionLimit, bool? useButtonsAllCaps, bool? replaceCancelButtonWithIcon, CameraPreviewMode? cameraPreviewMode, bool? touchToFocusEnabled, AspectRatio? aspectRatio, String? guidanceText, int? significantShakeDelay})

Properties

aspectRatio ↔ AspectRatio?
The cameras zoom level preferred for this step. The actual zoom might be different from the preferred one to avoid clipping of finder area and maintain its aspect ratio and height
getter/setter pair
cameraModule ↔ CameraModule?
The preferred camera module (default - BACK)
getter/setter pair
cameraOverlayColor ↔ Color?
Background color outside of the finder window.
getter/setter pair
cameraPreviewMode ↔ CameraPreviewMode?
Preview mode of the camera. FILL_IN or FIT_IN. Default is FILL_IN. Android only
getter/setter pair
cancelButtonHidden ↔ bool?
Whether the cancel button is hidden or not. iOS only.
getter/setter pair
cancelButtonTitle ↔ String?
Title of the cancel button.
getter/setter pair
enableCameraButtonTitle ↔ String?
Title of the button that opens the screen where the user can allow the usage of the camera by the app.
getter/setter pair
enableCameraExplanationText ↔ String?
Text that will be displayed when the app is not allowed to use the camera, prompting the user to enable the usage of the camera.
getter/setter pair
extractVINFromBarcode ↔ bool?
Controls whether the scanner should try to extract the VIN from possibly available barcodes. The default value is FALSE.
getter/setter pair
finderLineColor ↔ Color?
Foreground color of the detection overlay.
getter/setter pair
finderLineWidth ↔ double?
Width of finder frame border. Default is 2.
getter/setter pair
finderTextHintColor ↔ Color?
Foreground color of the description label.
getter/setter pair
flashButtonHidden ↔ bool?
Controls whether the flash toggle button is hidden or not. iOS only.
getter/setter pair
flashButtonTitle ↔ String?
Title of the flash toggle button. iOS only.
getter/setter pair
flashEnabled ↔ bool?
Controls whether the flash should be initially enabled. The default value is FALSE.
getter/setter pair
guidanceText ↔ String?
User guidance hint text.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
maximumNumberOfAccumulatedFrames ↔ int?
Maximum number of accumulated frames to inspect before actual result is returned
getter/setter pair
minimumNumberOfRequiredFramesWithEqualScanningResult ↔ int?
Minimum number of accumulated frames that have equal result
getter/setter pair
ocrResolutionLimit ↔ int?
The image will be downscaled to the given value during the processing. If the quality of the scanning is not enough, try to increase the limit. This variable affects the performance of the scanning process. Higher the size limit - better the quality, but the recognition is slower. 0 - do not rescale. Default value is 0.
getter/setter pair
orientationLockMode ↔ OrientationLockMode?
UI Interface orientation lock mode
getter/setter pair
replaceCancelButtonWithIcon ↔ bool?
If true, replaces the cancel button in the top bar with a back arrow icon. The default value is FALSE. Android only.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
screen ↔ String?
The configuration object should be applied for this screen
getter/setter pair
significantShakeDelay ↔ int?
Threshold used to pause the detection after significant movement occurred. Default = 0. Android only.
getter/setter pair
topBarBackgroundColor ↔ Color?
The background color of the top toolbar.
getter/setter pair
topBarButtonsActiveColor ↔ Color?
The color of all active toggle buttons in the toolbar.
getter/setter pair
topBarButtonsInactiveColor ↔ Color?
The color of all inactive toggle buttons in the toolbar.
getter/setter pair
touchToFocusEnabled ↔ bool?
Whether touch-to-focus is enabled on camera preview. Enabled by default. Android only.
getter/setter pair
useButtonsAllCaps ↔ bool?
Controls whether buttons should use all capitals style, as defined by the Android Material Design. Defaults to TRUE. Android only.
getter/setter pair
version ↔ String?
A version of the configuration object
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited