startScanner method

Opens the Ready-To-Use UI Text Pattern scanner with the desired configuration.

configuration - The Text Pattern scanner configuration to be used for scanning.

Returns a Future that completes with the result of the Text Pattern scanning operation.

Implementation

Future<Result<TextPatternScannerUiResult>> startScanner(
    TextPatternScannerScreenConfiguration configuration) {
  return ScanbotTextPatternImpl.startScanner(configuration);
}