ScanbotTiffGenerator class

Entry point for all TIFF generation features.

Constructors

ScanbotTiffGenerator()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

generateFromDocument(String documentUuid, TiffGeneratorParameters tiffGeneratorParameters) Future<Result<String>>
Creates a TIFF from the provided images with the specified configuration.
generateFromImageFileUris(List<String> images, TiffGeneratorParameters tiffGeneratorParameters) Future<Result<String>>
Creates a TIFF from the provided images with the specified configuration.
generateFromImageRefs(List<ImageRef> images, TiffGeneratorParameters tiffGeneratorParameters) Future<Result<String>>
Creates a TIFF from the provided images with the specified configuration.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited