generateFromImageRefs method

Future<Result<String>> generateFromImageRefs(
  1. List<ImageRef> images,
  2. TiffGeneratorParameters tiffGeneratorParameters
)

Creates a TIFF from the provided images with the specified configuration.

images - The list of images to be used for creating the TIFF. tiffGeneratorParameters - The configuration parameters for TIFF generation.

Returns a Future that completes with the file uri pointing to the generated TIFF file.

Implementation

Future<Result<String>> generateFromImageRefs(
    List<ImageRef> images, TiffGeneratorParameters tiffGeneratorParameters) {
  return ScanbotTiffGeneratorImpl.generateFromImageRefs(
      images, tiffGeneratorParameters);
}