ScanbotVin class

Entry point for all VIN scanning features.

Constructors

ScanbotVin()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startScanner(VinScannerScreenConfiguration configuration) Future<Result<VinScannerUiResult>>
Opens the Ready-To-Use UI VIN scanner with the desired configuration.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited