ScanbotCheck class

Entry point for all Check scanning features.

Constructors

ScanbotCheck()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scanFromImageFileUri(String image, CheckScannerConfiguration configuration) Future<Result<CheckScanningResult>>
Scans Check from a given image with the desired configuration.
scanFromImageRef(ImageRef image, CheckScannerConfiguration configuration) Future<Result<CheckScanningResult>>
Scans Check from a given image with the desired configuration.
startScanner(CheckScannerScreenConfiguration configuration) Future<Result<CheckScannerUiResult>>
Opens the Ready-To-Use UI Check scanner with the desired configuration.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited