startScanner method
Opens the Ready-To-Use UI Check scanner with the desired configuration.
configuration - The Check scanner configuration to be used for scanning.
Returns a Future that completes with the result of the Check scanning operation.
Implementation
Future<Result<CheckScannerUiResult>> startScanner(
CheckScannerScreenConfiguration configuration) {
return ScanbotCheckImpl.startScanner(configuration);
}