ScanbotDocument class
Entry point for all document features.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addPagesFromImageFileUris(
String documentUuid, List< String> images, {AddPageOptions? options}) → Future<Result< DocumentData> > - Adds new pages from the provided images to the document with the specified Uuid.
-
addPagesFromImageRefs(
String documentUuid, List< ImageRef> images, {AddPageOptions? options}) → Future<Result< DocumentData> > - Adds new pages from the provided images to the document with the specified Uuid.
-
analyzeQualityOnImageFileUri(
String image, DocumentQualityAnalyzerConfiguration configuration) → Future< Result< DocumentQualityAnalyzerResult> > - Analyzes the quality of the document on the provided image.
-
analyzeQualityOnImageRef(
ImageRef image, DocumentQualityAnalyzerConfiguration configuration) → Future< Result< DocumentQualityAnalyzerResult> > - Analyzes the quality of the document on the provided image.
-
cloneDocument(
String documentUuid) → Future< Result< DocumentData> > - Clones the document with the specified Uuid.
-
createDocumentFromImageFileUris(
{List< String> ? images, CreateDocumentOptions? options}) → Future<Result< DocumentData> > - Creates a document from the provided images with the specified options.
-
createDocumentFromImageRefs(
{List< ImageRef> ? images, CreateDocumentOptions? options}) → Future<Result< DocumentData> > - Creates a document from the provided images with the specified options.
-
createDocumentFromLegacyPages(
List< Page> pages, {int? documentImageSizeLimit}) → Future<Result< DocumentData> > - Creates a document from the provided legacy pages with the specified image size limit.
-
createDocumentFromPdf(
String pdfFileUri, {CreateDocumentOptions? options}) → Future< Result< DocumentData> > - Creates a document from the provided PDF file with the specified options.
-
deleteAllDocuments(
) → Future< Result< void> > - Deletes all stored documents.
-
deleteDocument(
String documentUuid) → Future< Result< void> > - Deletes the document with the specified Uuid.
-
documentExists(
String documentUuid) → Future< Result< bool> > - Checks if a document with the specified Uuid exists.
-
getStoredDocumentUuids(
) → Future< Result< List< >String> > - Retrieves the Uuids of all stored documents.
-
loadDocument(
String documentUuid) → Future< Result< DocumentData> > - Loads the document with the specified Uuid.
-
modifyPage(
String documentUuid, String pageUuid, {ModifyPageOptions? options}) → Future< Result< DocumentData> > - Modifies a page within the document using the specified options.
-
movePage(
String documentUuid, int fromIndex, int toIndex) → Future< Result< DocumentData> > - Moves a page within the document to a new position.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeAllPages(
String documentUuid) → Future< Result< DocumentData> > - Removes all pages from the document with the specified Uuid.
-
removePages(
String documentUuid, List< String> pageUuids) → Future<Result< DocumentData> > - Removes pages with the specified Uuids from the document.
-
scanFromImageFileUri(
String image, DocumentScannerConfiguration configuration) → Future< Result< DocumentScanningResult> > - Scans a document from the provided image.
-
scanFromImageRef(
ImageRef image, DocumentScannerConfiguration configuration) → Future< Result< DocumentScanningResult> > - Scans a document from the provided image.
-
startCroppingScreen(
CroppingConfiguration configuration) → Future< Result< DocumentData> > - Opens the Ready-To-Use UI Cropping screen with the desired configuration.
-
startScanner(
DocumentScanningFlow configuration) → Future< Result< DocumentData> > - Opens the Ready-To-Use UI Document Scanner screen with the desired configuration.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited