analyzeQualityOnImageFileUri method
Future<Result<DocumentQualityAnalyzerResult> >
analyzeQualityOnImageFileUri(
- String image,
- DocumentQualityAnalyzerConfiguration configuration
Analyzes the quality of the document on the provided image.
image - The image to be analyzed.
configuration - The configuration to be used for analysis.
Returns a Future that completes with result of the quality analysis.
Implementation
Future<Result<DocumentQualityAnalyzerResult>> analyzeQualityOnImageFileUri(
String image, DocumentQualityAnalyzerConfiguration configuration) {
return ScanbotDocumentImpl.analyzeQualityOnImageFileUri(
image, configuration);
}