modifyPage method
Future<Result<DocumentData> >
modifyPage(
- String documentUuid,
- String pageUuid, {
- ModifyPageOptions? options,
Modifies a page within the document using the specified options.
documentUuid - The Uuid of the document containing the page to be modified.
pageUuid - The Uuid of the page to be modified.
options - The options specifying the modifications to be made to the page.
Returns a Future that completes with updated document with the modified page.
Implementation
Future<Result<DocumentData>> modifyPage(String documentUuid, String pageUuid,
{ModifyPageOptions? options}) {
return ScanbotDocumentImpl.modifyPage(documentUuid, pageUuid, options);
}