removeAllPages method
Removes all pages from the document with the specified Uuid.
documentUuid - The Uuid of the document from which all pages will be removed.
Returns a Future that completes with updated document with all pages removed.
Implementation
Future<Result<DocumentData>> removeAllPages(String documentUuid) {
return ScanbotDocumentImpl.removeAllPages(documentUuid);
}