startCroppingScreen method

Future<Result<DocumentData>> startCroppingScreen(
  1. CroppingConfiguration configuration
)

Opens the Ready-To-Use UI Cropping screen with the desired configuration.

configuration - The configuration to be used for the cropping screen.

Returns a Future that completes with updated document after cropping.

Implementation

Future<Result<DocumentData>> startCroppingScreen(
    CroppingConfiguration configuration) {
  return ScanbotDocumentImpl.startCroppingScreen(configuration);
}