extractFromImageRef method
Future<Result<DocumentDataExtractionResult> >
extractFromImageRef(
- ImageRef image,
- DocumentDataExtractorConfiguration configuration
Extracts data from a given image with the desired configuration.
image - The image to be used for extracting.
configuration - The Document Data Extractor configuration to be used for extracting.
Returns a Future that completes with the result of the Document Data Extractor operation.
Implementation
Future<Result<DocumentDataExtractionResult>> extractFromImageRef(
ImageRef image, DocumentDataExtractorConfiguration configuration) {
return ScanbotDocumentDataExtractorImpl.extractFromImageRef(
image, configuration);
}