ScanbotDocumentEnhancer class
Entry point for all Document Enhancer features.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
straightenImageFileUri(
String image, DocumentStraighteningParameters straighteningParameters, {List< Point< ? priorCornersNormalized}) → Future<double> >Result< DocumentStraighteningResult> > - Straightens the document effectively straightening its edges and text.
-
straightenImageRef(
ImageRef image, DocumentStraighteningParameters straighteningParameters, {List< Point< ? priorCornersNormalized}) → Future<double> >Result< DocumentStraighteningResult> > - Straightens the document effectively straightening its edges and text.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited