startDocumentCleanupScreen method
Future<Result<DocumentData> >
startDocumentCleanupScreen(
- DocumentCleanupStandaloneConfiguration configuration
Opens the Ready-To-Use UI screen to clean up the document using the provided configuration.
configuration - The configuration to be used for the cleanup RTU-UI.
Returns a Future that completes with updated document after cleanup.
Implementation
Future<Result<DocumentData>> startDocumentCleanupScreen(
DocumentCleanupStandaloneConfiguration configuration) {
return ScanbotDocumentEnhancerImpl.startDocumentCleanupScreen(
configuration);
}