straightenImageRef method
Future<Result<DocumentStraighteningResult> >
straightenImageRef(
- ImageRef image,
- DocumentStraighteningParameters straighteningParameters, {
- List<
Point< ? priorCornersNormalized,double> >
Straightens the document effectively straightening its edges and text.
image - The image of the document to straighten.
straighteningParameters - The parameters to use for straightening.
priorCornersNormalized - If the corners are already known (e.g. from a prior detection), they can be provided here. The enhancer may take them into account to locate the document more accurately.
Returns a Future that completes with the result of the straightening operation.
Implementation
Future<Result<DocumentStraighteningResult>> straightenImageRef(
ImageRef image, DocumentStraighteningParameters straighteningParameters,
{List<Point<double>>? priorCornersNormalized}) {
return ScanbotDocumentEnhancerImpl.straightenImageRef(
image, straighteningParameters, priorCornersNormalized);
}