ScanbotImageProcessor class
Entry point for all image processing features.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
applyFilters(
ImageRef image, List< ParametricFilter> filters) → Future<Result< ImageRef> > - Applies the given filters on the image.
-
applyFiltersOnImageFile(
String imageFileUri, List< ParametricFilter> filters, {bool? overwrite, SaveImageOptions? saveOptions}) → Future<Result< String> > - Applies the given filters on the image.
-
crop(
ImageRef image, List< Point< polygon) → Future<double> >Result< ImageRef> > - Crops the image to the given polygon area.
-
cropImageFile(
String imageFileUri, List< Point< polygon, {bool? overwrite, SaveImageOptions? saveOptions}) → Future<double> >Result< String> > - Crops the image to the given polygon area.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
readImageData(
String imageFileUri) → Future< Result< String> > - Reads image data from the given file uri and returns it as a Base 64 encoded string.
-
resize(
ImageRef image, int maxSize) → Future< Result< ImageRef> > - Resizes the image to fit within the given maximum size for the longest edge.
-
resizeImageFile(
String imageFileUri, int maxSize, {bool? overwrite, SaveImageOptions? saveOptions}) → Future< Result< String> > - Resizes the image to fit within the given maximum size for the longest edge.
-
rotate(
ImageRef image, ImageRotation rotation) → Future< Result< ImageRef> > - Rotates the image by the given rotation degree. This methods must be wrapped inside an autorelease pool.
-
rotateImageFile(
String imageFileUri, ImageRotation rotation, {bool? overwrite, SaveImageOptions? saveOptions}) → Future< Result< String> > - Rotates the image by the given rotation degree.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited