resize method
Resizes the image to fit within the given maximum size for the longest edge.
image - Reference of the image to be resized.
maxSize - Maximum size for the longest edge of the image.
Returns a Future that completes with reference of the resized image.
Implementation
Future<Result<ImageRef>> resize(ImageRef image, int maxSize) {
return ScanbotImageProcessorImpl.resize(image, maxSize);
}