rotateImageFile method
Future<Result<String> >
rotateImageFile(
- String imageFileUri,
- ImageRotation rotation, {
- bool? overwrite,
- SaveImageOptions? saveOptions,
Rotates the image by the given rotation degree.
imageFileUri - File uri of the image to be rotated.
rotation - Rotation degree.
overwrite - Whether to overwrite the original image file or create a new file. Default is false
saveOptions - Options for saving the image.
Returns a Future that completes with file uri of the rotated image.
Implementation
Future<Result<String>> rotateImageFile(
String imageFileUri, ImageRotation rotation,
{bool? overwrite, SaveImageOptions? saveOptions}) {
return ScanbotImageProcessorImpl.rotateImageFile(
imageFileUri, rotation, overwrite, saveOptions);
}