ScanbotLegacyPage class
Entry point for all legacy page features.
- Annotations
-
- @Deprecated('Please, use ScanbotDocument instead.')
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
analyzeQualityOfDocument(
Page page, {Size? analyzerImageSizeLimit}) → Future< Result< DocumentQualityAnalyzerResult> > - Analyzes the documment quality of a given page.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
refreshImageUris(
List< Page> pages) → Future<Result< List< >Page> > - Recreates the given pages to refresh the image uris.
-
removeAllPages(
) → Future< Result< void> > - Remove all legacy pages from the storage.
-
removePage(
Page page) → Future< Result< void> > - Remove legacy page from the storage.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited