ScanbotOcrEngine class
Entry point for all OCR engine features.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
recognizeOnDocument(
String documentUuid, {OcrConfiguration? configuration}) → Future< Result< PerformOcrResult> > - Performs OCR on the provided document with the specified configuration.
-
recognizeOnImageFileUris(
List< String> images, {OcrConfiguration? configuration}) → Future<Result< PerformOcrResult> > - Performs OCR on the provided images with the specified configuration.
-
recognizeOnImageRefs(
List< ImageRef> images, {OcrConfiguration? configuration}) → Future<Result< PerformOcrResult> > - Performs OCR on the provided images with the specified configuration.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited