recognizeOnImageFileUris method
Future<Result<PerformOcrResult> >
recognizeOnImageFileUris(
- List<
String> images, { - OcrConfiguration? configuration,
Performs OCR on the provided images with the specified configuration.
images - The list of images to be used for OCR processing.
configuration - The configuration for OCR processing.
Returns a Future that completes with the result of the OCR processing.
Implementation
Future<Result<PerformOcrResult>> recognizeOnImageFileUris(List<String> images,
{OcrConfiguration? configuration}) {
return ScanbotOcrEngineImpl.recognizeOnImageFileUris(images, configuration);
}