generateFromDocument method
Future<Result<String> >
generateFromDocument(
- String documentUuid,
- PdfConfiguration pdfConfiguration, {
- OcrConfiguration? ocrConfiguration,
Creates a PDF from the provided images with the specified configuration.
documentUuid - The Uuid of the document to be used for creating the PDF.
pdfConfiguration - The configuration for the generated PDF.
ocrConfiguration - The configuration for OCR processing.
Returns a Future that completes with the file uri pointing to the generated PDF file.
Implementation
Future<Result<String>> generateFromDocument(
String documentUuid, PdfConfiguration pdfConfiguration,
{OcrConfiguration? ocrConfiguration}) {
return ScanbotPdfGeneratorImpl.generateFromDocument(
documentUuid, pdfConfiguration, ocrConfiguration);
}