generateFromImageRefs method
Future<Result<String> >
generateFromImageRefs(
- List<
ImageRef> images, - PdfConfiguration pdfConfiguration, {
- OcrConfiguration? ocrConfiguration,
Creates a PDF from the provided images with the specified configuration.
images - The list of images to be used for creating the PDF.
pdfConfiguration - The configuration for the generated PDF.
ocrConfiguration - The configuration for OCR processing.
Returns a Future that completes with the file uri pointing to the generated PDF file.
Implementation
Future<Result<String>> generateFromImageRefs(
List<ImageRef> images, PdfConfiguration pdfConfiguration,
{OcrConfiguration? ocrConfiguration}) {
return ScanbotPdfGeneratorImpl.generateFromImageRefs(
images, pdfConfiguration, ocrConfiguration);
}