DocumentData class
Document Data.
Constructors
Properties
- creationTimestamp → int
-
The creation timestamp of the document.
final
- documentImageSizeLimit → int
-
The maximum size of the document image.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
pages
→ List<
PageData> -
The list of pages.
final
- pdfURI → String
-
The URI of the default destination location for PDF rendering.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tiffURI → String
-
The URI of the default destination location for TIFF rendering.
final
- uuid → String
-
The unique identifier of the document.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
{ToJsonConfiguration? config}) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited