DocumentDetectionStatus enum
Status of the document detection.
Values
- NOT_ACQUIRED → const DocumentDetectionStatus
-
Detection has not yet happened.
- OK → const DocumentDetectionStatus
-
An acceptable document was detected.
- OK_BUT_TOO_SMALL → const DocumentDetectionStatus
-
A document was detected, but it is too small.
- OK_BUT_BAD_ANGLES → const DocumentDetectionStatus
-
A document was detected, but it has too much perspective distortion.
- OK_BUT_BAD_ASPECT_RATIO → const DocumentDetectionStatus
-
A document was detected, but its aspect ratio is not acceptable.
- OK_BUT_ORIENTATION_MISMATCH → const DocumentDetectionStatus
-
A document was detected, but its orientation does not match the input image orientation.
- OK_BUT_OFF_CENTER → const DocumentDetectionStatus
-
A document was detected, but its center is too far away from the input image center.
Deprecation Warning: This status is never returned by the document scanner.
- OK_BUT_TOO_DARK → const DocumentDetectionStatus
-
A document was detected, but it is too dark.
- OK_BUT_ALREADY_CROPPED → const DocumentDetectionStatus
-
Single-shot mode and ML engine mode only: No document was detected, likely because the input image is already cropped to the document.
This status indicates that the scanner confidence that the input is an image of a cropped document, given by the alreadyCroppedScore, is above the alreadyCroppedScoreThreshold.
- ERROR_NOTHING_DETECTED → const DocumentDetectionStatus
-
No document was detected.
- ERROR_PARTIALLY_VISIBLE → const DocumentDetectionStatus
-
ML engine mode only: A document was detected, but not all of its corners are visible.
Requires allowPartiallyVisibleDocuments to be true.
- ERROR_PARTIALLY_VISIBLE_TOO_CLOSE → const DocumentDetectionStatus
-
Live mode and ML engine mode only: A document was detected, but not all of its corners are visible and the document is too close to the camera.
Requires allowPartiallyVisibleDocuments to be true.
- ERROR_TOO_DARK → const DocumentDetectionStatus
-
No document was detected, likely because the input image is too dark.
- ERROR_TOO_NOISY → const DocumentDetectionStatus
-
No document was detected, likely because the input image is too noisy or has a complex background.
Deprecation Warning: This status is never returned by the document scanner.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
DocumentDetectionStatus> - A constant List of the values in this enum, in order of their declaration.