DocumentScannerConfiguration class
Configuration for the document scanner.
Constructors
- DocumentScannerConfiguration({DocumentScannerEngineMode engineMode = DocumentScannerEngineMode.ML, ProcessingMode processingMode = ProcessingMode.AUTO, DocumentScannerParameters? parameters, PartiallyVisibleDocumentConfiguration? partiallyVisibleDocumentConfiguration})
-
DocumentScannerConfiguration.fromJson(Map<
String, dynamic> json) -
factory
Properties
- engineMode ↔ DocumentScannerEngineMode
-
The engine to use for document scanning.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- parameters ↔ DocumentScannerParameters
-
Initial parameters for the document scanner.
getter/setter pair
- partiallyVisibleDocumentConfiguration ↔ PartiallyVisibleDocumentConfiguration
-
Configuration for handling partially visible documents.
getter/setter pair
- processingMode ↔ ProcessingMode
-
In live mode, the document scanner will return only the best document contour. In single-shot mode it will return additional document contours, suitable for use in the cropping screen.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
{ToJsonConfiguration? config}) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited