Page class
SDK Page
Constructors
-
Page({required String pageId, required List<
PolygonPoint> polygon, required DocumentDetectionStatus detectionResult, required PageImageSource pageImageSource, required ImageFilterType filter, List<ParametricFilter> ? parametricFilters, Size? documentImageSizeLimit, required String originalImageFileUri, String? documentImageFileUri, required String originalPreviewImageFileUri, String? documentPreviewImageFileUri}) -
Page.fromJson(Map<
String, dynamic> json) -
factory
Properties
- detectionResult ↔ DocumentDetectionStatus
-
The document detection result status for the operation that produced the page
getter/setter pair
- documentImageFileUri ↔ String?
-
File URI of the cropped document image (if document detection was successful)
getter/setter pair
- documentImageSizeLimit ↔ Size?
-
The value that was set for
documentImageSizeLimit, which limits the maximum size of the document image.getter/setter pair - documentPreviewImageFileUri ↔ String?
-
File URI of a screen-sized preview of the document image (if document detection was successful)
getter/setter pair
- filter ↔ ImageFilterType
-
The Image Filter that was applied on the page image. @deprecated Use parametricFilters instead.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- originalImageFileUri ↔ String
-
File URI of the original image
getter/setter pair
- originalPreviewImageFileUri ↔ String
-
File URI of a screen-sized preview of the original image
getter/setter pair
- pageId ↔ String
-
A string identifying the page in the internal page file storage
getter/setter pair
- pageImageSource ↔ PageImageSource
-
The image source
getter/setter pair
-
parametricFilters
↔ List<
ParametricFilter> ? -
The Image Filters that are applied on the page image
getter/setter pair
-
polygon
↔ List<
PolygonPoint> -
The page's cropping polygon as calculated by a document detection operation or as set by the cropping UI. Modifying the polygon will change the polygon as shown in the cropping UI but will not automatically re-crop the original image
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited