ScanbotSdk class

Entry point for all features that are part of Scanbot SDK.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

barcode ScanbotBarcode
Used for barcode scanning features.
getter/setter pair
check ScanbotCheck
Used for check scanning features.
getter/setter pair
creditCard ScanbotCreditCard
Used for credit card scanning features.
getter/setter pair
document ScanbotDocument
Used for document scanning features.
getter/setter pair
documentDataExtractor ScanbotDocumentDataExtractor
Used for document data extraction features.
getter/setter pair
imageProcessor ScanbotImageProcessor
Used for image processing features.
getter/setter pair
legacyPage ScanbotLegacyPage
Used for legacy page features.
getter/setter pair
mrz ScanbotMrz
Used for MRZ scanning features.
getter/setter pair
ocrEngine ScanbotOcrEngine
Used for OCR features.
getter/setter pair
pdfGenerator ScanbotPdfGenerator
Used for PDF generation features.
getter/setter pair
pdfImageExtractor ScanbotPdfImageExtractor
Used to extract images from PDF documents.
getter/setter pair
textPattern ScanbotTextPattern
Used for text pattern recognition features.
getter/setter pair
tiffGenerator ScanbotTiffGenerator
Used for TIFF generation features.
getter/setter pair
vin ScanbotVin
Used for VIN scanning features.
getter/setter pair

Static Methods

cleanupStorage() Future<Result<void>>
Cleans up the storage used by the Scanbot SDK.
getLicenseInfo() Future<Result<LicenseInfo>>
Provides complete information about the current license.
getOcrConfigs() Future<Result<OcrConfigsResult>>
Retrieves the OCR configurations available in the Scanbot SDK.
initialize(SdkConfiguration configuration) Future<Result<LicenseInfo>>
Initializes the Scanbot SDK with the preferred configuration.
mockCamera(String imageFileUri, {String? captureFileUri, bool? refreshOnEachFrame}) Future<Result<void>>
Mock camera preview by using static images as a frame source. This is useful for testing purposes.
setAnalyticsSubscriber(AnalyticsSubscriber? subscriber) Future<Result<void>>
Sets a custom analytics subscriber to receive analytics events from the Scanbot SDK.