mockCamera static method

Future<Result<void>> mockCamera(
  1. String imageFileUri, {
  2. String? captureFileUri,
  3. bool? refreshOnEachFrame,
})

Mock camera preview by using static images as a frame source. This is useful for testing purposes.

imageFileUri - The file uri of the image to be used as a mock camera frame. captureFileUri - The file uri of the image to be used as a mock captured frame. If not provided, the imageFileUri will be used. Default is "" refreshOnEachFrame - If true, the mock camera will refresh the frame on each request, simulating a live camera feed. Default is false

Implementation

static Future<Result<void>> mockCamera(String imageFileUri,
    {String? captureFileUri, bool? refreshOnEachFrame}) {
  return ScanbotSdkImpl.mockCamera(
      imageFileUri, captureFileUri, refreshOnEachFrame);
}