generateFromDocument method
Future<Result<String> >
generateFromDocument(
- String documentUuid,
- TiffGeneratorParameters tiffGeneratorParameters
Creates a TIFF from the provided images with the specified configuration.
documentUuid - The Uuid of the document to be used for creating the TIFF.
tiffGeneratorParameters - The configuration parameters for TIFF generation.
Returns a Future that completes with the file uri pointing to the generated TIFF file.
Implementation
Future<Result<String>> generateFromDocument(
String documentUuid, TiffGeneratorParameters tiffGeneratorParameters) {
return ScanbotTiffGeneratorImpl.generateFromDocument(
documentUuid, tiffGeneratorParameters);
}